MongoDB Profiler
================

A tool to profile MongoDB database operations and their implications on collections. It is not a monitoring tool, but suitable to collect metrics during load tests or to analyze and debug your database operations within a limited amount of time.

# Features
* Near real-time metrics of MongoDB operations (find, update, delete, getmore, findandmodify, count, aggregate, mapreduce)
* Identify problems of operations and check whether countermeasures have an effect
* Which operations do not use an index or scan more documents than necessary
* How many operations occur and in what proportion
* What are minimums, maximums and averages of lock acquisition, lock hold and execution time and identify outliers of those metrics
* How often are documents moved due to updates, which affects fragmentation and the volatility of your padding factor
* What are key metrics of your collections and how do they change over time

**Please note:** The profiler was developed step by step as OTTO moved forward with a deep analysis of MongoDB. The UI is not optimized. Graphs may crash your browser due to too many samples. And tests coverage is minimal.

# Requirements
* Java 7 (tested with Oracle JDK 1.7.0 u40)
* Servlet 3.0 compatible Servlet container (tested with Tomcat 7.0.42)
* Sufficient Heap, because data is kept in memory (2 GB recommended)
* Wide monitor (1680x1050 recommended)
* Tested with Firefox 24 and Chrome 30, Javascript is required
* Tested with MongoDB 2.4, but should work with 2.2
* Access to your database via TCP from the deployed application (low latency recommended)

# Create a deployable WAR
To build the profiler, you need to point your `JAVA_HOME` environment variable to a JDK 7. Make sure that you can access the internet, because dependencies will be acquired from Maven Central. Then execute Gradle 'war' task from inside the project directory:
```
% ./gradlew war
```
The war task will compile the project and create a WAR file which can be found in `mongodb-profiler-web/build/libs/mongodb-profiler-web.war` after the build completed.

## Build preferences
To change build preferences, create a `preferences.properties` inside the project directory. Following preferences can be set:
```
# The Maven repository to use.
mavenRepoUri=http://repo.mycompany.com

# The username to the Maven repository.
mavenRepoUser=myuser

# The password to the Maven repository.
mavenRepoPassword=mypassword
```
If you include credentials in the preferences, make sure the file's access rights are restricted properly.

# Installation / Deployment
Just deploy the WAR file in your servlet container - no special setup required.

If deployed as is into an unmodifed Tomcat, the application should become available at `http://localhost:8080/mongodb-profiler-web`.
