/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.ProfiledDatabase;
import de.otto.mongodb.profiler.collection.CollectionProfile;

import java.util.Locale;
import java.util.NoSuchElementException;

public class CollectionProfilePageViewModel extends CollectionProfileViewModel {

    private static CollectionProfile.Mark lastMark(CollectionProfile profile) {
        try {
            return profile.getMarks().getLast();
        } catch (NoSuchElementException e) {
            return null;
        }
    }

    private final CollectionProfile profile;
    private final ProfiledDatabase database;
    private final CollectionProfile.Mark lastMark;
    private final Locale locale;

    public CollectionProfilePageViewModel(final CollectionProfile profile,
                                          final ProfiledDatabase database,
                                          final Locale locale) {
        super(locale);
        this.profile = profile;
        this.database = database;
        this.lastMark = lastMark(profile);
        this.locale = locale;
    }

    public String getCollectionName() {
        return profile.getCollectionName();
    }

    public String getConnectionId() {
        return database.getConnection().getId();
    }

    public String getConnectionName() {
        return database.getConnection().getName();
    }

    public String getDatabaseName() {
        return database.getName();
    }

    public CollectionProfile getProfile() {
        return profile;
    }

    public boolean hasLastMark() {
        return lastMark != null;
    }

    public CollectionProfile.Mark getLastMark() {
        return lastMark;
    }
}
