/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.collection.CollectionProfile;
import de.otto.mongodb.profiler.collection.CollectionProfiler;
import org.joda.time.DateTime;

import java.text.Collator;
import java.util.ArrayList;
import java.util.Comparator;
import java.util.List;
import java.util.Locale;

import static java.util.Collections.sort;

public class CollectionProfilesPanelViewModel extends CollectionProfileViewModel {

    public static final Collator COLLATOR = Collator.getInstance(Locale.ENGLISH);

    public static final Comparator<CollectionProfile> COLLECTION_PROFILE_COMPARATOR = new Comparator<CollectionProfile>() {
        @Override
        public int compare(CollectionProfile left, CollectionProfile right) {

            if (left == right) {
                return 0;
            }

            if (left == null) {
                return -1;
            }

            if (right == null) {
                return 1;
            }

            return COLLATOR.compare(left.getCollectionName(), right.getCollectionName());
        }
    };

    public static enum RenderType {
        PANEL,
        TABLE;
    }

    private final String connectionId;
    private final String databaseName;
    private final List<? extends CollectionProfile> collectionProfiles;
    private final boolean profilingEnabled;
    private final DateTime profilingSince;
    private final List<String> availableCollections;
    private final RenderType renderType;

    public CollectionProfilesPanelViewModel(final String connectionId,
                                            final String databaseName,
                                            final CollectionProfiler profiler,
                                            final RenderType renderType,
                                            final Locale locale) {
        super(locale);
        this.connectionId = connectionId;
        this.databaseName = databaseName;
        this.collectionProfiles = new ArrayList<>(profiler.getProfiles());
        sort(this.collectionProfiles, COLLECTION_PROFILE_COMPARATOR);
        this.profilingEnabled = profiler.isProfiling();
        this.profilingSince = profiler.getProfilingStarted();
        this.availableCollections = new ArrayList<>(profiler.getAvailableCollections());
        sort(this.availableCollections, Collator.getInstance(Locale.ENGLISH));
        this.renderType = renderType;
    }

    public String getRenderType() {
        return renderType.name();
    }

    public String getConnectionId() {
        return connectionId;
    }

    public String getDatabaseName() {
        return databaseName;
    }

    public Iterable<? extends CollectionProfile> getCollectionProfiles() {
        return collectionProfiles;
    }


    public boolean isProfilingEnabled() {
        return profilingEnabled;
    }

    public DateTime getProfilingSince() {
        return profilingSince;
    }

    public List<String> getAvailableCollections() {
        return availableCollections;
    }
}
