/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.web.util.DataSizeFormat;
import org.joda.time.DateTime;

import java.lang.management.MemoryUsage;
import java.util.Locale;

public class FooterViewModel {

    private final MemoryUsage heap;
    private final DateTime runningSince;
    private final Locale locale;

    public FooterViewModel(final MemoryUsage heap,
                           final DateTime runningSince,
                           final Locale locale) {

        this.heap = heap;
        this.runningSince = runningSince;
        this.locale = locale;
    }

    public String humanReadable(long bytes) {
        return DataSizeFormat.format(bytes, locale);
    }

    public MemoryUsage getHeap() {
        return heap;
    }

    public DateTime getRunningSince() {
        return runningSince;
    }
}
