/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import java.text.Collator;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;
import java.util.Locale;

public class MainNavigationViewModel {

    public static class Connection {

        private final String id;
        private final String name;

        public Connection(String id, String name) {
            this.id = id;
            this.name = name;
        }

        public String getId() {
            return id;
        }

        public String getName() {
            return name;
        }
    }

    public static class Database {

        private final String name;
        private final Connection connection;

        public Database(final String name, final Connection connection) {
            this.name = name;
            this.connection = connection;
        }

        public String getName() {
            return name;
        }

        public Connection getConnection() {
            return connection;
        }
    }

    public static final Collator COLLATOR = Collator.getInstance(Locale.ENGLISH);

    public static final Comparator<Connection> CONNECTION_COMPARATOR = new Comparator<Connection>() {
        @Override
        public int compare(Connection left, Connection right) {
            return COLLATOR.compare(left.getName(), right.getName());
        }
    };

    public static final Comparator<Database> DATABASE_COMPARATOR = new Comparator<Database>() {
        @Override
        public int compare(Database left, Database right) {

            int diff = COLLATOR.compare(left.getName(), right.getName());

            if (diff != 0) {
                return diff;
            }

            return COLLATOR.compare(left.getConnection().getName(), right.getConnection().getName());
        }
    };

    private final String active;
    private final List<Connection> connections;
    private final List<Database> databases;

    public MainNavigationViewModel(final String active,
                                   final List<Connection> connections,
                                   final List<Database> databases) {
        this.active = active;
        this.connections = connections;
        Collections.sort(this.connections, CONNECTION_COMPARATOR);
        this.databases = databases;
        Collections.sort(this.databases, DATABASE_COMPARATOR);
    }

    public String getActive() {
        return active;
    }

    public List<Connection> getConnections() {
        return connections;
    }

    public List<Database> getDatabases() {
        return databases;
    }
}
