/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.AverageMeasure;
import de.otto.mongodb.profiler.ProfiledDatabase;
import de.otto.mongodb.profiler.op.*;
import de.otto.mongodb.profiler.web.util.BSONFormat;

import java.util.Collection;
import java.util.Locale;

public class OpProfilePageViewModel extends OpProfileViewModel {

    private final OpProfile profile;
    private final Object context;
    private final ProfiledDatabase database;
    private final boolean outliersAvailable;

    private final BSONFormat bsonFormat = BSONFormat.getTextInstance(2);

    protected OpProfilePageViewModel(final OpProfile profile,
                                     final ProfiledDatabase database,
                                     final Locale locale) {
        super(locale);
        this.profile = profile;
        this.context = OpProfileType.contextOf(profile);
        this.database = database;
        this.outliersAvailable = hasOutliers(profile);
    }

    public String getOpId() {
        return getProfile().getId();
    }

    public Object getContext() {
        return context;
    }

    public String getEventData(ProfileEntry event) {
        return bsonFormat.format(event.getData());
    }

    public boolean isExplainableOp() {
        return profile instanceof ExplainableOpProfile;
    }

    public String getExplanationData(Explanation explanation) {
        return bsonFormat.format(explanation.getData());
    }

    protected static boolean hasOutliers(Collection<AverageMeasure.Outlier> outliers) {
        return outliers != null && !outliers.isEmpty();
    }

    protected boolean hasOutliers(OpProfile profile) {
        final OpProfile.OutlierConfiguration config = profile.getOutlierConfiguration();
        return config != null &&
                config.captureOutliers()
                && (hasOutliers(profile.getAverageAcquireReadLockMicrosOutliers())
                || hasOutliers(profile.getAverageAcquireWriteLockMicrosOutliers())
                || hasOutliers(profile.getAverageLockedReadMicrosOutliers())
                || hasOutliers(profile.getAverageLockedWriteMicrosOutliers())
                || hasOutliers(profile.getAverageMillisOutliers()));
    }

    public boolean isOutliersAvailable() {
        return outliersAvailable;
    }

    public String getNs() {
        return profile.getNs();
    }

    public String getConnectionId() {
        return database.getConnection().getId();
    }

    public String getConnectionName() {
        return database.getConnection().getName();
    }

    public String getDatabaseName() {
        return database.getName();
    }

    public OpProfile getProfile() {
        return profile;
    }

}
