/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import com.mongodb.DBObject;
import de.otto.mongodb.profiler.op.AggregateProfile;
import de.otto.mongodb.profiler.op.MapReduceProfile;
import de.otto.mongodb.profiler.op.OpProfile;
import de.otto.mongodb.profiler.op.QueryProfile;
import de.otto.mongodb.profiler.web.util.BSONFormat;

import java.util.ArrayList;
import java.util.List;

public enum OpProfileType {

    QUERY(QueryProfile.class) {
        @Override
        public Object createContext(OpProfile profile) {
            final BSONFormat bsonFormat = BSONFormat.getTextInstance(2);
            return bsonFormat.format(((QueryProfile) profile).getQuery());
        }
    },
    AGGREGATE(AggregateProfile.class) {
        @Override
        public Object createContext(OpProfile profile) {
            final BSONFormat bsonFormat = BSONFormat.getTextInstance(2);
            final List<DBObject> pipeline = ((AggregateProfile) profile).getPipeline();
            final List<String> result = new ArrayList<>(pipeline.size());
            for (DBObject dbo : pipeline) {
                result.add(bsonFormat.format(dbo));
            }
            return result;
        }
    },
    MAP_REDUCE(MapReduceProfile.class) {
        @Override
        public Object createContext(OpProfile profile) {
            return profile;
        }
    };

    public final Class<? extends OpProfile> type;

    OpProfileType(Class<? extends OpProfile> type) {
        this.type = type;
    }

    public abstract Object createContext(OpProfile profile);

    public static Object contextOf(OpProfile profile) {
        for (OpProfileType context : OpProfileType.values()) {
            if (context.type.isInstance(profile)) {
                return context.createContext(profile);
            }
        }
        throw new RuntimeException(String.format("No context available for profile [%s]!", profile));
    }
}
