/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.AverageMeasure;
import de.otto.mongodb.profiler.op.OpProfile;
import de.otto.mongodb.profiler.op.UpdateProfile;

import java.math.BigDecimal;
import java.math.MathContext;
import java.math.RoundingMode;
import java.text.NumberFormat;
import java.util.Locale;

public abstract class OpProfileViewModel {

    public static String toPercent(BigDecimal value) {
        return value.movePointRight(2).setScale(0, RoundingMode.UP).toPlainString() + "%";
    }

    private final NumberFormat integerNumberFormat;

    protected OpProfileViewModel(Locale locale) {
        this.integerNumberFormat = NumberFormat.getIntegerInstance(locale);
        this.integerNumberFormat.setGroupingUsed(true);
        this.integerNumberFormat.setMaximumFractionDigits(0);
        this.integerNumberFormat.setMinimumFractionDigits(0);
    }

    public static final MathContext AVERAGE_INTEGER_MATH_CONTEXT = new MathContext(16, RoundingMode.UP);

    public String averageMillis(AverageMeasure measure) {
        return averageInteger(measure);
    }

    public String averageMicros(AverageMeasure measure) {
        return averageInteger(measure);
    }

    public String averageInteger(AverageMeasure measure) {
        return integerNumberFormat.format(measure.getAverage(AVERAGE_INTEGER_MATH_CONTEXT).intValue());
    }

    public String formatInteger(int value) {
        return integerNumberFormat.format(value);
    }

    public static boolean showMoveMeasureRatio(OpProfile profile) {
        return profile instanceof UpdateProfile;
    }

}
