/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.web.util;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.NumberFormat;
import java.util.Locale;

public class DataSizeFormat {

    public static enum Scale {

        BYTE("B", 0),
        KILOBYTE("KB", 0),
        MEGABYTE("MB", 1),
        GIGABYTE("GB", 4),
        TERRABYTE("TB", 6);

        public final String abbr;
        public final int scale;

        private Scale(final String abbr,
                      final int scale) {
            this.abbr = abbr;
            this.scale = scale;
        }

        public String format(BigDecimal decimal, Locale locale) {
            final NumberFormat format = NumberFormat.getInstance(locale);
            return format.format(decimal.setScale(scale, RoundingMode.HALF_UP)) + " " + abbr;
        }
    }

    private static final Scale FIRST = Scale.values()[Scale.values().length - 1];
    private static final BigDecimal SCALE_DIVISOR = BigDecimal.valueOf(1024L);

    public static String format(long bytes, Locale locale) {

        BigDecimal result = BigDecimal.valueOf(bytes);
        for (Scale scale : Scale.values()) {
            final BigDecimal candidate = result.divide(SCALE_DIVISOR);
            if (candidate.intValue() < 1) {
                return scale.format(result, locale);
            }
            result = candidate;
        }
        return FIRST.format(result, locale);
    }

}
