<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.CollectionProfilesPanelViewModel" -->
<#assign form=JspTaglibs["http://www.springframework.org/tags/form"]>
<#assign pageUri = "${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}" />
<#if model.renderType == "PANEL"><@panel><@table /></@panel></#if>
<#if model.renderType == "TABLE"><@table /></#if>

<#macro panel>
<div id="CollectionProfilesPanel" class="panel" data-fragment-src="${pageUri}/collections?render=panel">
    <a name="Collections"></a>
    <h3>${msg["collectionProfiles"]}</h3>
    <div class="panel panel-default">
        <div class="panel-body">
            <form method="post" class="f_controlForm" action="${pageUri}/collections/control" accept-charset="utf-8" data-reload-idref="CollectionProfilesPanel">
                <div class="btn-group">
                    <#if model.profilingEnabled>
                        <button type="submit" name="action" value="startProfiling" class="btn btn-default btn-sm" disabled="disabled" title="${msg["collectionProfiles.control.startProfiling"]}"><span class="glyphicon glyphicon-play"></span> ${msg["collectionProfiles.control.startProfiling"]}</button>
                        <button type="submit" name="action" value="stopProfiling" class="btn btn-default btn-sm" title="${msg["collectionProfiles.control.stopProfiling"]}" data-loading-text="${msg["collectionProfiles.control.stoppingProfiling"]}"><span class="glyphicon glyphicon-stop"></span> ${msg["collectionProfiles.control.stopProfiling"]}</button>
                    <#else>
                        <button type="submit" name="action" value="startProfiling" class="btn btn-default btn-sm" title="${msg["collectionProfiles.control.startProfiling"]}" data-loading-text="${msg["collectionProfiles.control.startingProfiling"]}"><span class="glyphicon glyphicon-play"></span> ${msg["collectionProfiles.control.startProfiling"]}</button>
                        <button type="submit" name="action" value="stopProfiling" class="btn btn-default btn-sm" title="${msg["collectionProfiles.control.stopProfiling"]}" disabled="disabled"><span class="glyphicon glyphicon-stop"></span> ${msg["collectionProfiles.control.stopProfiling"]}</button>
                    </#if>
                </div>
                <button type="submit" name="action" value="reset" class="next-control btn btn-default btn-sm" title="${msg["collectionProfiles.control.resetData"]}" data-loading-text="${msg["collectionProfiles.control.resettingData"]}"><span class="glyphicon glyphicon-trash"></span> ${msg["collectionProfiles.control.resetData"]}</button>
                <button type="submit" name="action" value="newSample" class="next-control btn btn-default btn-sm" title="${msg["collectionProfiles.control.collectSample"]}" data-loading-text="${msg["collectionProfiles.control.collectingSample"]}"><span class="glyphicon glyphicon-record"></span> ${msg["collectionProfiles.control.collectSample"]}</button>
            </form>
        </div>
    </div>
    <div class="alert alert-danger alert-dismissable" style="display: none;" data-alert-message="operation.failed">
        <button type="button" class="close" aria-hidden="true">&times;</button>
        <strong>${msg["collectionProfiles.error"]}</strong> ${msg["collectionProfiles.error.operationFailed"]}
    </div>
    <div class="alert alert-danger" style="display: none;" data-alert-message="collections.reload.failed">
        <strong>${msg["collectionProfiles.error"]}</strong> ${msg["collectionProfiles.error.reloadFailed"]}
    </div>
    <#nested />
    <div class="panel panel-default">
        <#if model.availableCollections?size gt 0>
            <div class="panel-body">
                <@form.form modelAttribute="collection" action="${pageUri}/collections" method="post" acceptCharset="utf-8" role="form" cssClass="form-inline">
                    <div class="form-group${global.hasFormError("name")?string(' has-error','')}">
                        <@form.label path="name" cssClass="sr-only">${msg["collectionProfiles.addCollection.name"]}</@form.label>
                        <@form.select path="name" cssClass="form-control">
                            <#list model.availableCollections as availableCollection>
                                <@form.option value=availableCollection label=availableCollection />
                            </#list>
                        </@form.select>
                    </div>
                    <button type="submit" class="btn btn-primary" name="addAll" value="false">${msg["collectionProfiles.addCollection.addSelected"]}</button>
                    <button type="submit" class="btn btn-primary" name="addAll" value="true">${msg["collectionProfiles.addCollection.addAll"]}</button>
                </@form.form>
            </div>
        <#else>
            <div class="panel-body">${msg["collectionProfiles.addCollection.nonAvailable"]}</div>
        </#if>
    </div>
</div>
</#macro>

<#macro table>
<table id="CollectionProfilesTable" class="profiler-table${model.profilingEnabled?string(' f_autoReloadFragment','')}" data-fragment-src="${pageUri}/collections?render=panel&renderType=table" data-reload-interval="60000" data-reload-alert="collections.reload.failed">
    <thead>
    <tr>
        <th>${msg["collectionProfiles.column.collection"]}</th>
        <th>${msg["collectionProfiles.column.dataSize"]}</th>
        <th>${msg["collectionProfiles.column.dataStorageSize"]}</th>
        <th>${msg["collectionProfiles.column.documentCount"]}</th>
        <th>${msg["collectionProfiles.column.averageDocumentCount"]}</th>
        <th>${msg["collectionProfiles.column.maximumDocumentCount"]}</th>
        <th>${msg["collectionProfiles.column.paddingFactor"]}</th>
        <th>${msg["collectionProfiles.column.averagePaddingFactor"]}</th>
        <th>${msg["collectionProfiles.column.minimumPaddingFactor"]}</th>
        <th>${msg["collectionProfiles.column.maximumPaddingFactor"]}</th>
        <th>${msg["collectionProfiles.column.sampleTime"]}</th>
    </tr>
    </thead>
    <tbody>
        <#if model.collectionProfiles?size gt 0>
            <#list model.collectionProfiles as profile>
                <#assign profilePageUrl = "${pageUri}/collections/${profile.collectionName}" />
                <tr>
                    <td>
                        <a href="${profilePageUrl}">${profile.collectionName}</a>
                        <#if profile.cappedCollection> <span class="meta-note">(capped)</span></#if>
                    </td>
                    <#if profile.dataAvailable>
                        <#assign mark = model.getLastMark(profile) />
                        <td>${model.getLastDataSize(mark)}</td>
                        <td>${model.getLastDataStorageSize(mark)}</td>
                        <td>${model.getLastDocunentCount(mark)}</td>
                        <td>${model.averageAbsolute(profile.documentCountMeasure)}</td>
                        <td>${model.formatInteger(profile.documentCountMeasure.max)}</td>
                        <td>${model.getLastPaddingFactor(mark)}</td>
                        <td>${model.averagePaddingFactor(profile.paddingFactorMeasure)}</td>
                        <td>${profile.paddingFactorMeasure.min}</td>
                        <td>${profile.paddingFactorMeasure.max}</td>
                        <td>${model.getLastSampleTime(mark)?replace(" ", "&nbsp;")}</td>
                    <#else>
                        <td colspan="10">${msg["collectionProfiles.noDataAvailable"]}</td>
                    </#if>
                </tr>
            </#list>
        <#else>
            <tr>
                <td colspan="11">${msg["collectionProfiles.noCollectionsAvailable"]}</td>
            </tr>
        </#if>
    </tbody>
    <tfoot>
        <tr class="info">
            <td colspan="15">
                <#if model.profilingEnabled>${msg("collectionProfiles.profilingSince", model.profilingSince)}<#else>${msg["collectionProfiles.notProfiling"]}</#if>,
            </td>
        </tr>
    </tfoot>
</table>
</#macro>