<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.OpProfilesPanelViewModel" -->
<#assign pageUri = "${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}" />
<#if model.renderType == "PANEL"><@panel><@table /></@panel></#if>
<#if model.renderType == "TABLE"><@table /></#if>

<#macro panel>
<div id="QueryProfilesPanel" class="panel" data-fragment-src="${pageUri}/ops?render=panel">
    <a name="OpProfiles"></a>
    <h3>${msg["opProfiles"]}</h3>
    <div class="panel panel-default">
        <div class="panel-body">
            <form id="QueryProfilesControl" method="post" class="form-inline f_controlForm" action="${pageUri}/ops/control" accept-charset="utf-8" role="form" data-reload-idref="QueryProfilesPanel">
                <div class="btn-group">
                    <#if model.profilingEnabled>
                        <button type="submit" name="action" value="startProfiling" class="btn btn-default btn-sm" title="${msg["opProfiles.control.startProfiling"]}" disabled="disabled"><span class="glyphicon glyphicon-play"></span> ${msg["opProfiles.control.startProfiling"]}</button>
                        <button type="submit" name="action" value="stopProfiling" class="btn btn-default btn-sm" title="${msg["opProfiles.control.stopProfiling"]}" data-loading-text="${msg["opProfiles.control.stoppingProfiling"]}"><span class="glyphicon glyphicon-stop"></span> ${msg["opProfiles.control.stopProfiling"]}</button>
                    <#else>
                        <button type="submit" name="action" value="startProfiling" class="btn btn-default btn-sm" title="${msg["opProfiles.control.startProfiling"]}" data-loading-text="${msg["opProfiles.control.startingProfiling"]}"><span class="glyphicon glyphicon-play"></span> ${msg["opProfiles.control.startProfiling"]}</button>
                        <button type="submit" name="action" value="stopProfiling" class="btn btn-default btn-sm" title="${msg["opProfiles.control.stopProfiling"]}" disabled="disabled"><span class="glyphicon glyphicon-stop"></span> ${msg["opProfiles.control.stopProfiling"]}</button>
                    </#if>
                </div>
                <button type="submit" name="action" value="reset" class="next-control btn btn-default btn-sm" title="${msg["opProfiles.control.resetData"]}" data-loading-text="${msg["opProfiles.control.resettingData"]}"><span class="glyphicon glyphicon-trash"></span> ${msg["opProfiles.control.resetData"]}</button>
                <button type="submit" name="action" value="explainNextQueries" class="next-control btn btn-default btn-sm" title="${msg["opProfiles.control.explainNextQueries"]}" data-loading-text="${msg["opProfiles.control.explainingNextQueries"]}">${msg["opProfiles.control.explainNextQueries"]}</button>
                <div class="next-control form-group">
                    <#assign currentLevel = model.profilingLevel.value />
                    <label for="QueryProfilesControl_level" class="sr-only">${msg["opProfiles.control.changeProfilingLevel"]}</label>
                    <select id="QueryProfilesControl_level" name="level" class="form-control">
                        <option value="0"${(currentLevel==0)?string(' selected="selected"','')}>${msg["opProfiles.control.changeProfilingLevel.level.off"]}</option>
                        <option value="1"${(currentLevel==1)?string(' selected="selected"','')}>${msg["opProfiles.control.changeProfilingLevel.level.slowOps"]}</option>
                        <option value="2"${(currentLevel==2)?string(' selected="selected"','')}>${msg["opProfiles.control.changeProfilingLevel.level.allOps"]}</option>
                    </select>
                </div>
                <button type="submit" name="action" value="changeProfilingLevel" class="btn btn-primary btn-sm" title="${msg["opProfiles.control.changeProfilingLevel"]}" data-loading-text="${msg["opProfiles.control.changingProfilingLevel"]}">${msg["opProfiles.control.changeProfilingLevel"]}</button>
                <a class="next-control btn btn-sm btn-default" href="${pageUri}/ops/control?action=changeOutlierConfiguration" title="${msg["opProfiles.control.changeOutlierConfiguration"]}"><#if model.outlierConfigurationEnabled><span class="glyphicon glyphicon-ok"></span> </#if>${msg["opProfiles.control.changeOutlierConfiguration"]}</a>
            </form>
        </div>
    </div>
    <div class="alert alert-danger alert-dismissable" style="display: none;" data-alert-message="operation.failed">
        <button type="button" class="close" aria-hidden="true">&times;</button>
        <strong>${msg["opProfiles.error"]}</strong> ${msg["opProfiles.error.operationFailed"]}
    </div>
    <div class="alert alert-danger" style="display: none;" data-alert-message="queryProfiles.reload.failed">
        <strong>${msg["opProfiles.error"]}</strong> ${msg["opProfiles.error.reloadFailed"]}
    </div>
    <#nested />
    <dl class="explanation">
        <#list 1..5 as definition>
            <dd>${msg["opProfiles.definitions." + definition]}</dd>
        </#list>
    </dl>
</div>
</#macro>

<#macro table>
<table id="QueryProfilesTable" class="profiler-table${model.profilingEnabled?string(' f_autoReloadFragment','')}" data-fragment-src="${pageUri}/ops?render=panel&renderType=table" data-reload-interval="10000" data-reload-alert="queryProfiles.reload.failed">
    <thead>
        <tr>
            <th>${msg["opProfiles.column.namespace"]}</th>
            <th>${msg["opProfiles.column.type"]}</th>
            <th>${msg["opProfiles.column.context"]}</th>
            <th>${msg["opProfiles.column.numberOfEventsAndExplanations"]}</th>
            <th>${msg["opProfiles.column.eventProportions"]}</th>
            <th>${msg["opProfiles.column.averageExecutionTime"]}</th>
            <th>${msg["opProfiles.column.minimumExecutionTime"]}</th>
            <th>${msg["opProfiles.column.maximumExecutionTime"]}</th>
            <th>${msg["opProfiles.column.averageLockAcquisitionTime"]}</th>
            <th>${msg["opProfiles.column.minimumLockAcquisitionTime"]}</th>
            <th>${msg["opProfiles.column.maximumLockAcquisitionTime"]}</th>
            <th>${msg["opProfiles.column.averageLockTime"]}</th>
            <th>${msg["opProfiles.column.minimumLockTime"]}</th>
            <th>${msg["opProfiles.column.maximumLockTime"]}</th>
            <th>${msg["opProfiles.column.documentMoveRatio"]}</th>
        </tr>
    </thead>
    <tbody>
        <#if model.profiles?size gt 0>
            <#list model.profiles as profile>
                <#assign profilePageUrl = "${pageUri}/ops/${profile.id}" />
                <#assign severityClass = "" />
                <#if model.hasSevereIssue(profile)>
                    <#assign severityClass = "severe-issue" />
                <#elseif model.hasWarningIssue(profile)>
                    <#assign severityClass = "warning-issue" />
                </#if>
                <tr class="${severityClass}">
                    <td>
                        <a href="${profilePageUrl}">${profile.ns}</a>
                    </td>
                    <td class="nobr">
                    ${profile.type}<#if profile.type == "findandmodify"> <span class="meta-note">(${profile.outcome})</span></#if>
                    </td>
                    <#assign profileContext = model.getContext(profile) />
                    <#if profile.type == "mapreduce">
                        <td class="mapreduce-context">
                            <pre>var map = ${profileContext.mapFunction?html};</pre>
                            <pre>var reduce = ${profileContext.reduceFunction?html};</pre>
                        </td>
                        <td>${model.formatInteger(profile.eventCount)} / -</td>
                    <#elseif profile.type == "aggregate">
                        <td class="aggregate-context">
                            <ol>
                                <#list profileContext as pipelineStep>
                                    <li>${pipelineStep?html}</li>
                                </#list>
                            </ol>
                        </td>
                        <td>${model.formatInteger(profile.eventCount)} / -</td>
                    <#else>
                        <td>
                            <a href="${profilePageUrl}">${profileContext?html}</a>
                        </td>
                        <td>${model.formatInteger(profile.eventCount)} / ${model.formatInteger(profile.explanationCount)}</td>
                    </#if>
                    <td>${model.getEventCountProportion(profile)}</td>
                    <td>${model.averageMillis(profile.averageMillis)}</td>
                    <td>${profile.averageMillis.min}</td>
                    <td>${profile.averageMillis.max}</td>
                    <td>${model.averageMicros(profile.averageAcquireReadLockMicros)}&nbsp;/&nbsp;${model.averageMicros(profile.averageAcquireWriteLockMicros)}</td>
                    <td>${model.formatInteger(profile.averageAcquireReadLockMicros.min)}&nbsp;/&nbsp;${model.formatInteger(profile.averageAcquireWriteLockMicros.min)}</td>
                    <td>${model.formatInteger(profile.averageAcquireReadLockMicros.max)}&nbsp;/&nbsp;${model.formatInteger(profile.averageAcquireWriteLockMicros.max)}</td>
                    <td>${model.averageMicros(profile.averageLockedReadMicros)}&nbsp;/&nbsp;${model.averageMicros(profile.averageLockedWriteMicros)}</td>
                    <td>${model.formatInteger(profile.averageLockedReadMicros.min)}&nbsp;/&nbsp;${model.formatInteger(profile.averageLockedWriteMicros.min)}</td>
                    <td>${model.formatInteger(profile.averageLockedReadMicros.max)}&nbsp;/&nbsp;${model.formatInteger(profile.averageLockedWriteMicros.max)}</td>
                    <#if model.showMoveMeasureRatio(profile)>
                        <td>${model.toPercent(profile.moveMeasure.getRatio())}</td>
                    <#else>
                        <td>-</td>
                    </#if>
                </tr>
            </#list>
        <#else>
        <tr>
            <td colspan="15">${msg["opProfiles.noDataAvailable"]}</td>
        </tr>
        </#if>
    </tbody>
    <tfoot>
        <#if model.profiles?size gt 0>
            <tr class="totals">
                <td colspan="3">${msg["collectionProfiles.totals"]}</td>
                <td>${model.formatInteger(model.totalEventCount)}&nbsp;/&nbsp;${model.formatInteger(model.totalExplanationCount)}</td>
                <td>100%</td>
                <td colspan="10"></td>
            </tr>
        </#if>
        <tr class="info">
            <#if model.profilingEnabled>
                <td colspan="15">${msg("opProfiles.profilingSince", model.profilingSince)}</td>
            <#else>
                <td colspan="15">${msg["opProfiles.notProfiling"]}</td>
            </#if>
        </tr>
    </tfoot>
</table>
</#macro>
