<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.CollectionProfilePageViewModel" -->
<#assign form=JspTaglibs["http://www.springframework.org/tags/form"]>
<#import "charts.ftl" as charts />
<#assign extraJs = charts.js + ["/profiler/js/collection-profile.js"] />
<#assign extraCss = charts.css + ["/profiler/css/collection-profile.css"] />
<@layout.standard title=msg("page.collectionProfile", model.collectionName) extraCss=extraCss extraJs=extraJs>
    <#assign pageUri = "${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}/collections/${model.collectionName}" />
    <ol class="breadcrumb">
        <li><a href="${rc.contextPath}/connections">${msg["breadcrumb.connections"]}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}">${msg("breadcrumb.connections.connection", model.connectionName)}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}">${msg("breadcrumb.connections.connection.database", model.databaseName)}</a></li>
        <li class="active">${msg("breadcrumb.connections.connection.database.collection", model.collectionName)}</li>
    </ol>
    <div class="page-header">
        <h1>${msg("page.collectionProfile.headline", model.collectionName)} <small>${msg("page.collectionProfile.headline.small", model.databaseName)}</small></h1>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.collectionProfile.statistics"]}</h3>
        </div>
        <div class="panel-body">
            <#assign profile = model.profile />
            <#if model.hasLastMark()>
                <#assign mark = model.lastMark />
                <table class="stats">
                    <tbody>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.samples"]}</td>
                        <td>${model.formatInteger(model.profile.marks?size)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.lastSampleTime"]}</td>
                        <td>${model.getLastSampleTime(mark)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.dataSize"]}</td>
                        <td>${model.getLastDataSize(mark)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.dataStorageSize"]}</td>
                        <td>${model.getLastDataStorageSize(mark)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.documentCount"]}</td>
                        <td>${model.getLastDocunentCount(mark)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.averageDocumentCount"]}</td>
                        <td>${model.averageAbsolute(profile.documentCountMeasure)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.maximumDocumentCount"]}</td>
                        <td>${model.formatInteger(profile.documentCountMeasure.max)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.paddingFactor"]}</td>
                        <td>${model.getLastPaddingFactor(mark)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.averagePaddingFactor"]}</td>
                        <td>${model.averagePaddingFactor(profile.paddingFactorMeasure)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.minimumPaddingFactor"]}</td>
                        <td>${profile.paddingFactorMeasure.min}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.collectionProfile.statistics.maximumPaddingFactor"]}</td>
                        <td>${profile.paddingFactorMeasure.max}</td>
                    </tr>
                    </tbody>
                </table>
            <#else>
                ${msg["page.collectionProfile.statistics.noData"]}
            </#if>
        </div>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.collectionProfile.documentCount"]}</h3>
        </div>
        <div class="panel-body">
            <@charts.standardChart id="DocumentCountChart" src="${pageUri}/chart-data/document-count" />
        </div>
        <#if model.hasLastMark()>
            <ul class="list-group">
                <li class="list-group-item">${msg("page.collectionProfile.documentCount.documentCount", model.lastMark.documentCount)}</li>
            </ul>
        </#if>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.collectionProfile.paddingFactor"]}</h3>
        </div>
        <div class="panel-body">
            <@charts.standardChart id="PaddingFactorChart" src="${pageUri}/chart-data/padding-factor" />
        </div>
        <#if model.hasLastMark()>
            <ul class="list-group">
                <li class="list-group-item">${msg("page.collectionProfile.paddingFactor.paddingFactor", model.lastMark.paddingFactor)}</li>
            </ul>
        </#if>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.collectionProfile.dataSize"]}</h3>
        </div>
        <div class="panel-body">
            <@charts.standardChart id="DataSizeChart" src="${pageUri}/chart-data/data-size" />
        </div>
        <#if model.hasLastMark()>
            <ul class="list-group">
                <li class="list-group-item">${msg("page.collectionProfile.dataSize.dataSize", model.formatBytes(model.lastMark.dataSize))}</li>
                <li class="list-group-item">${msg("page.collectionProfile.dataSize.dataStorageSize", model.formatBytes(model.lastMark.dataStorageSize))}</li>
            </ul>
        </#if>
    </div>
</@layout.standard>
