<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.ConnectionPageViewModel" -->
<#assign form=JspTaglibs["http://www.springframework.org/tags/form"]>
<@layout.standard title=msg("page.connection", model.name)>
    <#assign pageUri = "${rc.contextPath}/connections/${model.id}" />
    <ol class="breadcrumb">
        <li><a href="${rc.contextPath}/connections">${msg["breadcrumb.connections"]}</a></li>
        <li class="active">${msg("breadcrumb.connections.connection", model.name)}</li>
    </ol>
    <div class="page-header">
        <h1>${msg("page.connection.headline", model.name)} <small>${msg["page.connection.headline.small"]}</small></h1>
    </div>
    <div class="panel">
        <h3>${msg["page.connection.databases"]}</h3>
        <table class="table table-hover table-condensed">
            <thead>
                <tr>
                    <th>${msg["page.connection.databases.column.name"]}</th>
                </tr>
            </thead>
            <tbody>
                <#if model.databases?size gt 0>
                    <#list model.databases as database>
                        <tr>
                            <td><a href="${pageUri}/databases/${database.name}">${database.name}</a></td>
                        </tr>
                    </#list>
                <#else>
                    <tr>
                        <td>${msg["page.connection.databases.noDataAvailable"]}</td>
                    </tr>
                </#if>
            </tbody>
        </table>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">${msg["page.connection.addDatabase"]}</div>
        <div class="panel-body">
            <@form.form modelAttribute="database" action="${rc.contextPath}/connections/${model.id}/databases" method="post" acceptCharset="utf-8" role="form">
                <@form.errors element="div" cssClass="alert alert-danger" />
                <div class="form-group${global.hasFormError("name")?string(' has-error','')}">
                    <@form.label path="name" cssClass="control-label" required="required">${msg["page.connection.addDatabase.name"]}</@form.label>
                    <@form.input path="name" cssClass="form-control" />
                    <@form.errors path="name" element="div" cssClass="form-error" />
                </div>
                <div class="form-group${global.hasFormError("username")?string(' has-error','')}">
                    <@form.label path="username" cssClass="control-label">${msg["page.connection.addDatabase.username"]}</@form.label>
                    <@form.input path="username" cssClass="form-control" />
                    <@form.errors path="username" element="div" cssClass="form-error" />
                </div>
                <div class="form-group${global.hasFormError("password")?string(' has-error','')}">
                    <@form.label path="password" cssClass="control-label">${msg["page.connection.addDatabase.password"]}</@form.label>
                    <@form.password path="password" cssClass="form-control" />
                    <@form.errors path="password" element="div" cssClass="form-error" />
                </div>
                <div>
                    <button type="button" class="btn btn-default f_linkButton" data-href="${rc.contextPath}/connections/${model.id}" data-confirm="${msg["page.connection.addDatabase.cancel.confirm"]}">${msg["page.connection.addDatabase.cancel"]}</button>
                    <button type="submit" class="btn btn-primary">${msg["page.connection.addDatabase.submit"]}</button>
                </div>
            </@form.form>
        </div>
    </div>
    <div class="panel panel-default">
        <div class="panel-body">
            <form action="${rc.contextPath}/connections/${model.id}/destroy" method="post">
                <button type="submit" class="btn btn-danger btn-sm">${msg["page.connection.destroyConnection"]}</button>
            </form>
        </div>
    </div>
</@layout.standard>
