<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.OpOutlierConfigurationPageViewModel" -->
<#assign extraJs = ["/profiler/js/op-outlierconfig.js"] />
<@layout.standard title=msg["page.opOutlierConfig"] extraJs=extraJs>
    <#assign form=JspTaglibs["http://www.springframework.org/tags/form"]>
    <ol class="breadcrumb">
        <li><a href="${rc.contextPath}/connections">${msg["breadcrumb.connections"]}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}">${msg("breadcrumb.connections.connection", model.connectionName)}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}">${msg("breadcrumb.connections.connection.database", model.databaseName)}</a></li>
        <li class="active">${msg["breadcrumb.connections.connection.database.opOutlierConfiguration"]}</li>
    </ol>
    <div class="page-header">
        <h1>${msg["page.opOutlierConfig.headline"]}</h1>
    </div>
    <#assign pageUri = rc.contextPath + "/connections/" + model.connectionId + "/databases/" + model.databaseName + "/ops/control?action=changeOutlierConfiguration" />
    <div class="panel">
        <p>${msg["page.opOutlierConfig.introduction"]}</p>
        <@form.form modelAttribute="configuration" action="${pageUri}" method="post" acceptCharset="utf-8" role="form">
            <@form.errors element="div" cssClass="alert alert-danger" />
            <div class="form-group${global.hasFormError("enabled")?string(' has-error','')}">
                <label for="OutlierConfig_enabled" class="control-label checkbox-label">
                    <@form.checkbox id="OutlierConfig_enabled" path="enabled" cssClass="f_enablingToggle" /> ${msg["page.opOutlierConfig.form.enableConfig"]}
                </label>
                <@form.errors path="enabled" element="div" cssClass="form-error" />
            </div>
            <div id="OutlierConfigDetails">
                <div class="form-group${global.hasFormError("strategy")?string(' has-error','')}">
                    <@form.label path="strategy" cssClass="control-label">${msg["page.opOutlierConfig.form.strategy"]}</@form.label>
                    <@form.select path="strategy" cssClass="form-control">
                        <#list model.outlierStrategies as outlierStrategy>
                            <@form.option value=outlierStrategy.value>${msg["page.opOutlierConfig.form.strategy." + outlierStrategy.name()]}</@form.option>
                        </#list>
                    </@form.select>
                    <@form.errors path="strategy" element="div" cssClass="form-error" />
                </div>
                <div class="form-group${global.hasFormError("ignoreOutliers")?string(' has-error','')}">
                    <label class="control-label checkbox-label">
                        <@form.checkbox path="ignoreOutliers" /> ${msg["page.opOutlierConfig.form.ignoreOutliers"]}
                    </label>
                    <@form.errors path="ignoreOutliers" element="div" cssClass="form-error" />
                </div>
                <div class="form-group${global.hasFormError("captureOutliers")?string(' has-error','')}">
                    <label class="control-label checkbox-label">
                        <@form.checkbox path="captureOutliers" /> ${msg["page.opOutlierConfig.form.captureOutliers"]}
                    </label> ${msg["page.opOutlierConfig.form.captureOutliers.note"]}
                    <@form.errors path="captureOutliers" element="div" cssClass="form-error" />
                </div>
                <div class="form-group">
                    ${msg["page.opOutlierConfig.form.changeWarning"]}
                </div>
            </div>
            <#if !model.outlierConfigurationEnabled>
                <script type="text/javascript" language="JavaScript">
                    $(document).ready(function () {
                        $('#OutlierConfigDetails').hide(1);
                    });
                </script>
            </#if>
            <div>
                <button type="button" class="btn btn-default f_linkButton" title="${msg["page.opOutlierConfig.form.cancel"]}" data-href="${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}/ops" data-confirm="${msg["page.opOutlierConfig.form.cancel.confirm"]}">${msg["page.opOutlierConfig.form.cancel"]}</button>
                <button type="submit" class="btn btn-primary" title="${msg["page.opOutlierConfig.form.submit"]}">${msg["page.opOutlierConfig.form.submit"]}</button>
            </div>
        </@form.form>
    </div>
</@layout.standard>
