<#--

     Copyright 2013 Robert Gacki <robert.gacki@cgi.com>

     Licensed under the Apache License, Version 2.0 (the "License");
     you may not use this file except in compliance with the License.
     You may obtain a copy of the License at

         http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing, software
     distributed under the License is distributed on an "AS IS" BASIS,
     WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
     See the License for the specific language governing permissions and
     limitations under the License.

-->
<#-- @ftlvariable name="msg" type="freemarker.ext.beans.ResourceBundleModel" -->
<#-- @ftlvariable name="rc" type="org.springframework.web.servlet.support.RequestContext" -->
<#-- @ftlvariable name="model" type="de.otto.mongodb.profiler.web.OpProfilePageViewModel" -->
<#assign form=JspTaglibs["http://www.springframework.org/tags/form"]>
<#import "charts.ftl" as charts />
<#assign extraJs = charts.js + ["/profiler/js/op-profile.js", '/daterangepicker/moment.min.js', '/daterangepicker/daterangepicker.js'] />
<#assign extraCss = charts.css + ["/profiler/css/op-profile.css", '/daterangepicker/daterangepicker-bs3.css'] />
<#assign profile = model.profile />
<#assign queryTypes = ["query", "update", "findandmodify", "count", "getmore"] />
<@layout.standard title=msg("page.opProfile", model.ns, model.opId) extraCss=extraCss extraJs=extraJs>
    <#assign pageUri = "${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}/ops/${model.opId}" />
    <ol class="breadcrumb">
        <li><a href="${rc.contextPath}/connections">${msg["breadcrumb.connections"]}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}">${msg("breadcrumb.connections.connection", model.connectionName)}</a></li>
        <li><a href="${rc.contextPath}/connections/${model.connectionId}/databases/${model.databaseName}">${msg("breadcrumb.connections.connection.database", model.databaseName)}</a></li>
        <li class="active">${msg["breadcrumb.connections.connection.database.op"]}</li>
    </ol>
    <div class="page-header">
        <#-- Maps the object's type to the message key suffix. A missing type is "!unknown". -->
        <#assign titles = {"query": "find", "update": "update", "findandmodify": "findandmodify","count": "count","getmore": "getmore","mapreduce": "mapreduce","aggregate": "aggregate"} />
        <h1>${msg("page.opProfile.headline", msg["page.opProfile.type." + titles[profile.type]!"unknown"])} <small>${msg("page.opProfile.headline.small", model.ns)}</small></h1>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.opProfile.context"]}</h3>
        </div>
        <div class="panel-body">
            <#if queryTypes?seq_contains(profile.type)>
                ${msg["page.opProfile.context.query"]}
                <pre>${model.context}</pre>
            <#elseif profile.type == "aggregate">
                ${msg["page.opProfile.context.pipeline"]}
                <ol>
                    <#list model.context as pipelineEntry>
                        <li><pre>${pipelineEntry}</pre></li>
                    </#list>
                </ol>
            <#elseif profile.type == "mapreduce">
                <span>${msg["page.opProfile.context.mapreduce.map"]}</span>
                <pre>${model.context.mapFunction}</pre>
                <span>${msg["page.opProfile.context.mapreduce.reduce"]}</span>
                <pre>${model.context.reduceFunction}</pre>
            </#if>
        </div>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.opProfile.statistics"]}</h3>
        </div>
        <div class="panel-body">
            <#assign profile = model.profile />
            <table class="stats">
                <tbody>
                    <tr>
                        <td>${msg["page.opProfile.statistics.samples"]}</td>
                        <td colspan="3">${model.formatInteger(profile.eventCount)}</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.averageExecutionTime"]}</td>
                        <td colspan="3">${model.averageMillis(profile.averageMillis)} ms</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.minimumExecutionTime"]}</td>
                        <td colspan="3">${model.formatInteger(profile.averageMillis.min)} ms</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.maximumExecutionTime"]}</td>
                        <td colspan="3">${model.formatInteger(profile.averageMillis.max)} ms</td>
                    </tr>
                    <#if profile.averageMillis.outlierCount gt 0>
                        <tr>
                            <td>${msg["page.opProfile.statistics.executionTimeOutliers"]}</td>
                            <td><@statsGraphLink value=profile.averageMillis.outlierCount datum="executionTimeOutliers" scale="ms" /></td>
                        </tr>
                    </#if>
                    <tr>
                        <td>${msg["page.opProfile.statistics.averageReadLockAcquisitionTime"]}</td>
                        <td>${model.averageMicros(profile.averageAcquireReadLockMicros)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.averageWriteLockAcquisitionTime"]}</td>
                        <td>${model.averageMicros(profile.averageAcquireWriteLockMicros)} &micro;s</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.minimumReadLockAcquisitionTime"]}</td>
                        <td>${model.formatInteger(profile.averageAcquireReadLockMicros.min)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.minimumWriteLockAcquisitionTime"]}</td>
                        <td>${model.formatInteger(profile.averageAcquireWriteLockMicros.min)} &micro;s</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.maximumReadLockAcquisitionTime"]}</td>
                        <td>${model.formatInteger(profile.averageAcquireReadLockMicros.max)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.maximumWriteLockAcquisitionTime"]}</td>
                        <td>${model.formatInteger(profile.averageAcquireWriteLockMicros.max)} &micro;s</td>
                    </tr>
                    <#if profile.averageAcquireReadLockMicros.outlierCount gt 0 || profile.averageAcquireWriteLockMicros.outlierCount gt 0>
                        <tr>
                            <#if profile.averageAcquireReadLockMicros.outlierCount gt 0>
                                <td>${msg["page.opProfile.statistics.readLockAcquisitionTimeOutliers"]}</td>
                                <td><@statsGraphLink value=model.formatInteger(profile.averageAcquireReadLockMicros.outlierCount) datum="readLockAcquisitionTimeOutliers" scale="&micro;s" /></td>
                            <#else>
                                <td></td>
                                <td></td>
                            </#if>
                            <#if profile.averageAcquireWriteLockMicros.outlierCount gt 0>
                                <td>${msg["page.opProfile.statistics.writeLockAcquisitionTimeOutliers"]}</td>
                                <td><@statsGraphLink value=model.formatInteger(profile.averageAcquireWriteLockMicros.outlierCount) datum="writeLockAcquisitionTimeOutliers" scale="&micro;s" /></td>
                            <#else>
                                <td></td>
                                <td></td>
                            </#if>
                        </tr>
                    </#if>
                    <tr>
                        <td>${msg["page.opProfile.statistics.averageReadLockTime"]}</td>
                        <td>${model.averageMicros(profile.averageLockedReadMicros)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.averageWriteLockTime"]}</td>
                        <td>${model.averageMicros(profile.averageLockedWriteMicros)} &micro;s</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.minimumReadLockTime"]}</td>
                        <td>${model.formatInteger(profile.averageLockedReadMicros.min)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.minimumWriteLockTime"]}</td>
                        <td>${model.formatInteger(profile.averageLockedWriteMicros.min)} &micro;s</td>
                    </tr>
                    <tr>
                        <td>${msg["page.opProfile.statistics.maximumReadLockTime"]}</td>
                        <td>${model.formatInteger(profile.averageLockedReadMicros.max)} &micro;s</td>
                        <td>${msg["page.opProfile.statistics.maximumWriteLockTime"]}</td>
                        <td>${model.formatInteger(profile.averageLockedWriteMicros.max)} &micro;s</td>
                    </tr>
                    <#if profile.averageLockedReadMicros.outlierCount gt 0 || profile.averageLockedWriteMicros.outlierCount gt 0>
                        <tr>
                            <#if profile.averageLockedReadMicros.outlierCount gt 0>
                                <td>${msg["page.opProfile.statistics.readLockTimeOutliers"]}</td>
                                <td><@statsGraphLink value=model.formatInteger(profile.averageLockedReadMicros.outlierCount) datum="readLockTimeOutliers" scale="&micro;s" /></td>
                            <#else>
                                <td></td>
                                <td></td>
                            </#if>
                            <#if profile.averageLockedWriteMicros.outlierCount gt 0>
                                <td>${msg["page.opProfile.statistics.writeLockTimeOutliers"]}</td>
                                <td><@statsGraphLink value=model.formatInteger(profile.averageLockedWriteMicros.outlierCount) datum="writeLockTimeOutliers" scale="&micro;s" /></td>
                            <#else>
                                <td></td>
                                <td></td>
                            </#if>
                        </tr>
                    </#if>
                    <#if profile.averageYieldCount.count gt 0>
                        <tr>
                            <td>${msg["page.opProfile.statistics.averageYieldCount"]}</td>
                            <td colspan="3">${model.averageInteger(profile.averageYieldCount)}</td>
                        </tr>
                        <tr>
                            <td>${msg["page.opProfile.statistics.minimumYieldCount"]}</td>
                            <td colspan="3">${model.formatInteger(profile.averageYieldCount.min)}</td>
                        </tr>
                        <tr>
                            <td>${msg["page.opProfile.statistics.maximumYieldCount"]}</td>
                            <td colspan="3">${model.formatInteger(profile.averageYieldCount.max)}</td>
                        </tr>
                    </#if>
                    <#if model.showMoveMeasureRatio(profile)>
                        <tr>
                            <td>${msg["page.opProfile.statistics.movedDocumentRatio"]}</td>
                            <td colspan="3">${model.toPercent(profile.moveMeasure.getRatio())}</td>
                        </tr>
                    </#if>
                </tbody>
            </table>
            <#if model.outliersAvailable>
                <div id="StatsGraph" style="display: none;">
                    <div class="alert f_alertTemplate" style="display: none;" data-remove-on-dismissal="true" data-errormessage="Failed to load graph data. Please change the graph configuration or reload this page if it occurs again.">
                        <a class="close" data-dismiss="alert" href="#" aria-hidden="true">&times;</a>
                    </div>
                    <svg id="StatsGraph_svg"></svg>
                    <div class="button-group">
                        <button class="btn btn-default btn-sm f_showStatsGraphControlModal" data-toggle="modal" data-target="#StatsGraphControlModal">${msg["page.opProfile.statistics.outlierGraph.configure"]}</button>
                    </div>
                    <div id="StatsGraphControlModal" class="modal fade" style="display: none;">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <button type="button" class="close" data-dismiss="modal" aria-hidden="true">&times;</button>
                                    <h4 class="modal-title">${msg["page.opProfile.statistics.outlierGraph.form"]}</h4>
                                </div>
                                <form id="StatsGraphControl" action="${pageUri}/stats" method="get" role="form">
                                    <div class="modal-body">
                                        <div class="form-group">
                                            <label for="StatsGraphControl_datum" class="control-label">${msg["page.opProfile.statistics.outlierGraph.form.datum"]}</label>
                                            <select id="StatsGraphControl_datum" name="datum" multiple="multiple" class="form-control">
                                                <#if profile.averageMillis.outlierCount gt 0>
                                                    <option value="executionTimeOutliers" data-scale="ms">${msg["page.opProfile.statistics.outlierGraph.form.datum.executionTimeOutliers"]}</option>
                                                </#if>
                                                <#if profile.averageAcquireReadLockMicros.outlierCount gt 0>
                                                    <option value="readLockAcquisitionTimeOutliers" data-scale="&micro;s">${msg["page.opProfile.statistics.outlierGraph.form.datum.readLockAcquisitionTimeOutliers"]}</option>
                                                </#if>
                                                <#if profile.averageAcquireWriteLockMicros.outlierCount gt 0>
                                                    <option value="writeLockAcquisitionTimeOutliers" data-scale="&micro;s">${msg["page.opProfile.statistics.outlierGraph.form.datum.writeLockAcquisitionTimeOutliers"]}</option>
                                                </#if>
                                                <#if profile.averageLockedReadMicros.outlierCount gt 0>
                                                    <option value="readLockTimeOutliers" data-scale="&micro;s">${msg["page.opProfile.statistics.outlierGraph.form.datum.readLockTimeOutliers"]}</option>
                                                </#if>
                                                <#if profile.averageLockedWriteMicros.outlierCount gt 0>
                                                    <option value="writeLockTimeOutliers" data-scale="&micro;s">${msg["page.opProfile.statistics.outlierGraph.form.datum.writeLockTimeOutliers"]}</option>
                                                </#if>
                                            </select>
                                        </div>
                                        <div class="form-group">
                                            <label for="StatsGraphControl_limit" class="control-label">${msg["page.opProfile.statistics.outlierGraph.form.limit"]}</label>
                                            <input id="StatsGraphControl_limit" type="text" name="limit" value="" class="form-control" placeholder="Value limit" />
                                        </div>
                                        <div class="form-group">
                                            <label for="StatsGraphControl_min" class="control-label">${msg["page.opProfile.statistics.outlierGraph.form.min"]}</label>
                                            <input id="StatsGraphControl_min" type="text" name="min" value="" class="form-control" placeholder="Minimum value" />
                                        </div>
                                        <div class="form-group">
                                            <label for="StatsGraphControl_max" class="control-label">${msg["page.opProfile.statistics.outlierGraph.form.max"]}</label>
                                            <input id="StatsGraphControl_max" type="text" name="max" value="" class="form-control" placeholder="Maximum value" />
                                        </div>
                                        <div class="form-group">
                                            <label for="StatsGraphControl_timerange" class="control-label">${msg["page.opProfile.statistics.outlierGraph.form.fromTo"]}</label>
                                            <input id="StatsGraphControl_timerange" type="text" name="timeRange" value="" class="form-control f_dateRangePicker" placeholder="Time range" data-format="${msg["page.opProfile.statistics.outlierGraph.form.fromTo.format"]}" />
                                            <input type="hidden" name="from" value="" />
                                            <input type="hidden" name="to" value="" />
                                        </div>
                                    </div>
                                    <div class="modal-footer">
                                        <button type="button" class="btn btn-default" title="${msg["page.opProfile.statistics.outlierGraph.form.cancel"]}" data-dismiss="modal">${msg["page.opProfile.statistics.outlierGraph.form.cancel"]}</button>
                                        <button type="submit" class="btn btn-primary" title="${msg["page.opProfile.statistics.outlierGraph.form.submit"]}">${msg["page.opProfile.statistics.outlierGraph.form.submit"]}</button>
                                    </div>
                                </form>
                            </div>
                        </div>
                    </div>
                </div>
            </#if>
        </div>
    </div>
    <#assign issues = profile.issues />
    <#if issues?size gt 0>
        <form id="OpProfileIssuesControl" action="${pageUri}/issues" method="post" accept-charset="utf-8" role="form" class="f_opIssueControl">
            <#list issues as issue>
                <div class="alert alert-warning">
                    <div class="control">
                        <button type="submit" name="dismiss" value="${issue.code}" class="btn btn-default btn-sm" title="${msg["page.opProfile.issues.dismiss"]}" data-loading-text="${msg["page.opProfile.issues.dismissing"]}"><span class="glyphicon glyphicon-trash"></span> ${msg["page.opProfile.issues.dismiss"]}</button>
                    </div>
                    <#assign issueMsgKey = "page.opProfile.issues.issue." + issue.code />
                    <#assign issueMsg = msg[issueMsgKey] />
                    <#if issueMsg == ("???" + issueMsgKey + "???")>${msg("page.opProfile.issues.issue.unknown", issue.code)}<#else>${issueMsg}</#if>
                </div>
            </#list>
        </form>
    </#if>
    <#if model.explainableOp>
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">${msg["page.opProfile.explanations"]}</h3>
            </div>
            <#if profile.explanationCount gt 0>
                <ul class="list-group">
                    <#list profile.explanations as explaination>
                        <li class="list-group-item">
                            <p><span class="meta-note">${explaination.createdAt}</span></p>
                            <#if explaination.issues?size gt 0>
                                <#list explaination.issues as issue>
                                    <#assign alertCss = "alert-warning" />
                                    <#if issue.severity?string == "SEVERE"><#assign alertCss = "alert-danger" /></#if>
                                    <div class="alert ${alertCss}"><strong>${msg["page.opProfile.explanations.issues.severity." + issue.severity.name()]}</strong> ${msg["page.opProfile.explanations.issues.issue." + issue.code]}</div>
                                </#list>
                            </#if>
                            <pre>${model.getExplanationData(explaination)}</pre>
                        </li>
                    </#list>
                </ul>
            <#else>
                <div class="panel-body">
                    ${model.context}
                </div>
            </#if>
        </div>
    </#if>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">${msg["page.opProfile.lastEvent"]}</h3>
        </div>
        <div class="panel-body">
            <#assign lastEvent = profile.lastEvent />
            <#if lastEvent??>
                <pre>${model.getEventData(lastEvent)}</pre>
            <#else>
                No event available.
            </#if>
        </div>
    </div>
    <#if profile.type == "update">
        <div class="panel panel-default">
            <div class="panel-heading">
                <h3 class="panel-title">${msg["page.opProfile.movedDocuments"]}</h3>
            </div>
            <div class="panel-body">
                <@charts.standardChart id="MovedDocumentChart" src="${pageUri}/chart-data/moved-documents" charts=2 />
            </div>
        </div>
    </#if>
</@layout.standard>

<#macro statsGraphLink value datum scale><#if model.outliersAvailable><a href="${pageUri}/stats" class="f_showStatsGraph" title="${msg["page.opProfile.statistics.showGraph"]}" data-datum="${datum}" data-scale="${scale}" data-overlay-idref="StatsGraph">${value} <span class="glyphicon glyphicon-stats"></span></a><#else>${value}</#if></#macro>