var profiler = profiler || {};
profiler.collectionProfile = profiler.collectionProfile || {};

profiler.collectionProfile.showDocumentCountChart = function ($chart, data) {
    var svgSelector = '#' + $chart.attr('id') + ' svg';
    nv.addGraph(function () {
        var chart = nv.models.lineChart()
            .x(function(d) { return d[0]; })
            .y(function(d) { return d[1]; })
            .color(d3.scale.category10().range())
            .margin({left: 100, right: 100});
        chart.xAxis
            .tickFormat(function(d) {
                return d3.time.format('%H:%M%:%S')(new Date(d))
            });
        chart.yAxis
            .tickFormat(d3.format('d'));
        d3.select(svgSelector)
            .datum([data.documentCount])
            .transition().duration(500)
            .call(chart);
        nv.utils.windowResize(chart.update);
        return chart;
    });
};

profiler.collectionProfile.showPaddingFactorChart = function ($chart, data) {
    var svgSelector = '#' + $chart.attr('id') + ' svg';
    nv.addGraph(function () {
        var chart = nv.models.lineChart()
            .x(function(d) { return d[0]; })
            .y(function(d) { return d[1]; })
            .color(d3.scale.category10().range())
            .margin({left: 150, right: 100});
        chart.xAxis
            .tickFormat(function(d) {
                return d3.time.format('%H:%M%:%S')(new Date(d))
            });
        chart.yAxis
            .tickFormat(d3.format('.16g'));
        chart.yAxis
            .scale().domain([1,2,3,4]);
        d3.select(svgSelector)
            .datum([data.paddingFactor])
            .transition().duration(500)
            .call(chart);
        nv.utils.windowResize(chart.update);
        return chart;
    });
};

profiler.collectionProfile.formatByte = function (d) {
    var result = d,
        measures = ["TB", "GB", "MB", "KB", "B"];
    while (measures.length > 0) {
        var measure = measures.pop();
        var candidate = result / 1024;
        if (candidate < 1 || measures.length == 0) {
            return d3.format(',.2r')(result) + ' ' + measure;
        }
        result = candidate;
    }
};

profiler.collectionProfile.showDataSizeChart = function ($chart, data) {
    var svgSelector = '#' + $chart.attr('id') + ' svg';
    nv.addGraph(function () {
        var chart = nv.models.lineChart()
            .x(function(d) { return d[0]; })
            .y(function(d) { return d[1]; })
            .color(d3.scale.category10().range())
            .margin({left: 100, right: 100});
        chart.xAxis
            .tickFormat(function(d) {
                return d3.time.format('%H:%M%:%S')(new Date(d))
            });
        chart.yAxis
            .tickFormat(function (d) {
                return profiler.collectionProfile.formatByte(d);
            });
        d3.select(svgSelector)
            .datum([data.dataSize, data.dataStorageSize])
            .transition().duration(500)
            .call(chart);
        nv.utils.windowResize(chart.update);
        return chart;
    });
};

$(document).ready(function () {

    if (!profiler.chart) {
        throw new Error('profiler.chart api required!');
    }

    var cm = profiler.chart.createManager(),
        cp = profiler.collectionProfile;

    cm.createChart('#DocumentCountChart', cp.showDocumentCountChart).load();
    cm.createChart('#PaddingFactorChart', cp.showPaddingFactorChart).load();
    cm.createChart('#DataSizeChart', cp.showDataSizeChart).load();
});
