'use strict';

var profiler = profiler || {};

profiler.queryParams = function (obj) {
    'use strict';

    var params = [];
    _.each(obj, function (value, key) {
        if (typeof value === 'array') {
            _.each(value, function (valueVal) {
                if (valueVal !== null) {
                    params.push(encodeURIComponent(key) + '=' + encodeURIComponent(valueVal));
                }
            });
        } else {
            if (value !== null) {
                params.push(encodeURIComponent(key) + '=' + encodeURIComponent(value));
            }
        }
    });
    return params.join('&');
};

profiler.onLinkButtonClick = function () {
    'use strict';

    var $this = $(this),
        target = $this.data('href'),
        confirm = $this.data('confirm');
    if (target && (target + '') !== '') {
        if (confirm && (confirm + '') !== '') {
            if (!window.confirm(confirm)) {
                return false;
            }
        }
        window.location.href = target;
    }
    return false;
};

profiler.disableButtonsIn = function ($target, button) {
    'use strict';

    $target.find('button').each(function () {
        if (button && button == this) {
            $(this).button('loading');
        } else {
            var $this = $(this);
            if ($this.attr('disabled') === 'disabled' || $this.is(':disabled')) {
                $this.data('disabled-default', 'disabled');
            } else {
                $this.attr('disabled', 'disabled');
            }
        }
    });
};

profiler.enableButtonsIn = function ($target, button) {
    'use strict';

    $target.find('button').each(function () {
        if (button && button == this) {
            $(this).button('reset');
        } else {
            var $this = $(this);
            if ($this.data('disabled-default') !== 'disabled') {
                $(this).removeAttr('disabled');
            }
        }
    });
};

profiler.loadLazyContent = function ($target) {
    'use strict';

    var src = $target.data('src'),
        options = {
            method: 'GET'
        },
        onDone = function (content) {
            var $content = $(content);
            $target.replaceWith(content);
            profiler.bindScoped($content);
        };

    $.ajax(src, options).done(onDone);
};

profiler.createFragmentReloader = function ($target, loaded) {
    'use strict';

    var id = $target.attr('id'),
        src = $target.data('fragment-src'),
        ajaxOptions = {
            method: 'GET',
            dataType: 'html'
        },
        onDone = function replaceReloadedFragment(content) {
            $('#' + id).replaceWith(content);
            if (typeof loaded === 'function') {
                loaded.call(this);
            }
        },
        onFailure = function showAlertAfterFragmentReloadFailed() {
            var alertMessage = $target.data('reload-alert') + '';
            if (alertMessage !== '') {
                $('.alert').filter(function () {
                    return $(this).data('alert-message') === alertMessage;
                }).first().show();
            }
        };

    return function reloadFragment() {
        $.ajax(src, ajaxOptions).done(onDone).fail(onFailure);
    };
};

profiler.autoReloadFragment = function ($target) {
    'use strict';

    var interval = $target.data('reload-interval') || 30000,
        reloader, onTimeout;

    onTimeout = function () {
        reloader.call(this);
    };

    reloader = this.createFragmentReloader($target, function reloadAgain() {
        setTimeout(onTimeout, interval);
    });

    setTimeout(onTimeout, interval);
};

profiler.onControlFormButtonClick = function () {
    'use strict';

    var $button = $(this);

    if ($button.hasClass('dropdown-toggle')) {
        return true;
    }

    var that = this,
        $form = $button.parents('form').first(),
        reloadTargetId = '#' + $form.data('reload-idref'),
        action = $form.attr('action'),
        $reloadTarget = $(reloadTargetId),
        buttonParam = $button.attr('name') + '=' + $button.attr('value'),
        ajaxConfig = {
            method: $form.attr('method'),
            data: $form.serialize()
        },
        afterReload = function () {
            profiler.bindScoped($(reloadTargetId));
        },
        fragmentReloader = profiler.createFragmentReloader($reloadTarget, afterReload),
        onDone = function () {
            fragmentReloader.call(this);
        },
        onFailure = function () {
            $reloadTarget.find('.alert').each(function () {
                var $alert = $(this);
                if ($alert.data('alert-message') === 'operation.failed') {
                    $alert.show();
                }
            });
            profiler.enableButtonsIn($form, that);
        };

    if (ajaxConfig.data !== '') {
        ajaxConfig.data += '&';
    }

    ajaxConfig.data += buttonParam;

    profiler.disableButtonsIn($form, that);

    // May be too fast for the user to acknowledge that something happened
    setTimeout(function () {
        $.ajax(action, ajaxConfig).done(onDone).fail(onFailure);
    }, 500);

    return false;
};

profiler.bindScoped = function ($scope) {
    'use strict';

    $scope.find('.f_lazyContent').each(function () {
        profiler.loadLazyContent($(this));
    });
    $scope.find('.f_autoReloadFragment').each(function () {
        profiler.autoReloadFragment($(this));
    });
};

profiler.closeAlert = function (e) {
    'use strict';

    e.preventDefault();

    var $this = $(this).parents('.alert').first(),
        removeOnDismissal = $this.data('remove-on-dismissal');
    $this.hide(500, function () {
        if (removeOnDismissal) {
            $(this).remove();
        }
    });
    return false;
};

$(document).ready(function () {
    var $d = $(document);
    $d.on('click', '.f_linkButton', profiler.onLinkButtonClick);
    $d.on('click', '.f_showInpageHelp', profiler.onShowInpageHelp);
    $d.on('click', '.f_controlForm button', profiler.onControlFormButtonClick);
    $d.on('click', '.alert .close', profiler.closeAlert);
    profiler.bindScoped($d);
});
