'use strict';

var profiler = profiler || {};
profiler.opProfile = profiler.opProfile || {};

profiler.opProfile.showDocumentMoveCharts = function ($chart, data) {
    'use strict';

    var ratioSvgSelector = '#' + $chart.attr('id') + '_svg_1';
    var totalsSvgSelector = '#' + $chart.attr('id') + '_svg_2';

    nv.addGraph(function () {
        var chart = nv.models.lineChart()
            .x(function (d) {
                return d[0];
            })
            .y(function (d) {
                return d[1];
            })
            .color(d3.scale.category10().range())
            .margin({left: 100, right: 100});
        chart.xAxis
            .tickFormat(function (d) {
                return d3.time.format('%H:%M%:%S')(new Date(d))
            });
        chart.yAxis
            .tickFormat(d3.format('d'));
        d3.select(ratioSvgSelector)
            .datum([data.ratio])
            .transition().duration(500)
            .call(chart);
        nv.utils.windowResize(chart.update);
        return chart;
    });

    nv.addGraph(function () {
        var chart = nv.models.lineChart()
            .x(function (d) {
                return d[0];
            })
            .y(function (d) {
                return d[1];
            })
            .color(d3.scale.category10().range())
            .margin({left: 100, right: 100});
        chart.xAxis
            .tickFormat(function (d) {
                return d3.time.format('%H:%M%:%S')(new Date(d))
            });
        chart.yAxis
            .tickFormat(d3.format('d'));
        d3.select(totalsSvgSelector)
            .datum([data.total, data.moved])
            .transition().duration(500)
            .call(chart);
        nv.utils.windowResize(chart.update);
        return chart;
    });
};

profiler.opProfile.issueControl = function () {
    'use strict';

    var that = this,
        $button = $(this),
        $alert = $button.parents('.alert').first(),
        buttonParam = $button.attr('name') + '=' + $button.attr('value'),
        $form = $button.parents('form.f_opIssueControl').first(),
        action = $form.attr('action'),
        ajaxConfig = {
            method: $form.attr('method'),
            data: $form.serialize()
        },
        onDone = function () {
            $alert.alert('close');
        };

    if (ajaxConfig.data !== '') {
        ajaxConfig.data += '&';
    }

    ajaxConfig.data += buttonParam;

    profiler.disableButtonsIn($alert, that);

    // May be too fast for the user to acknowledge that something happened
    setTimeout(function () {
        $.ajax(action, ajaxConfig).done(onDone);
    }, 500);

    return false;
};

profiler.opProfile.loadStatsGraphDefaults = {
    min: null,
    max: null,
    limit: null,
    datum: null,
    from: null,
    to: null
};

profiler.opProfile.onStatsGraphDatePickerChange = function (start, end) {
    $('#StatsGraphControl input[name="from"]').val(start.valueOf());
    $('#StatsGraphControl input[name="to"]').val(end.valueOf());
};

profiler.opProfile.loadStatsGraph = function (src, options) {
    'use strict';

    options = _.extend({}, profiler.opProfile.loadStatsGraphDefaults, options);

    src += '?' + profiler.queryParams({
        datum: options.datum,
        min: options.min,
        max: options.max,
        limit: options.limit,
        from: options.from,
        to: options.to
    });

    var $overlay = $('#StatsGraph'),
        ajaxConfig = {
            method: 'GET',
            headers: {
                'Accept': 'application/json'
            },
            dataType: 'json'
        },
        onDone = function (data) {

            var outliers = data['outliers'];

            // Show warnings
            if (outliers['warnings']) {
                var warnings = outliers['warnings'],
                    $alertTemplate = $('#StatsGraph .f_alertTemplate'),
                    $alert = $alertTemplate.clone().removeClass('f_alertTemplate').addClass('alert-warning');
                _.each(outliers['warnings'], function (warning) {
                    $alert.append('<p>' + warning + '</p>');
                });
                $alertTemplate.before($alert);
                $alert.show();
            }

            // Update the control form
            var params = outliers['params'];
            if (params) {
                $('#StatsGraphControl input[name="limit"]').val(params['limit'] && params['limit'] !== null ? params['limit'] : '');
                $('#StatsGraphControl input[name="min"]').val(params['min'] && params['min'] !== null ? params['min'] : '');
                $('#StatsGraphControl input[name="max"]').val(params['max'] && params['max'] !== null ? params['max'] : '');
                if (params['datum']) {
                    var $options = $('#StatsGraphControl select[name="datum"] option');
                    $options.each(function () {
                        this.selected = false;
                    });
                    _.each(params['datum'], function (datum) {
                        $options.each(function () {
                            var $option = $(this);
                            if ($option.val() === datum) {
                                this.selected = true;
                            }
                        });
                    });
                }

                // Change the date picker values
                var $picker = $('#StatsGraphControl .f_dateRangePicker'),
                    pickerOpts = {
                    timePicker: true,
                    timePickerIncrement: 5,
                    format: $picker.data('format')
                };

                $('#StatsGraphControl input[name="from"]').val(params['from'] && params['from'] !== null ? params['from'] : '');
                $('#StatsGraphControl input[name="to"]').val(params['to'] && params['to'] !== null ? params['to'] : '');

                if (params['from'] && params['from'] !== null) {
                    pickerOpts.startDate = new Date(params['from']);
                    if (outliers['lowestTime'] && outliers['lowestTime'] !== null) {
                        pickerOpts.minDate = new Date(outliers['lowestTime']);
                    }
                } else {
                    if (outliers['lowestTime'] && outliers['lowestTime'] !== null) {
                        pickerOpts.startDate = new Date(outliers['lowestTime']);
                        pickerOpts.minDate = new Date(outliers['lowestTime']);
                    }
                }

                if (params['to'] && params['to'] !== null) {
                    pickerOpts.endDate = new Date(params['to']);
                    if (outliers['highestTime'] && outliers['highestTime'] !== null) {
                        pickerOpts.maxDate = new Date(outliers['highestTime']);
                    }
                } else {
                    if (outliers['highestTime'] && outliers['highestTime'] !== null) {
                        pickerOpts.endDate = new Date(outliers['highestTime']);
                        pickerOpts.maxDate = new Date(outliers['highestTime']);
                    }
                }

                $picker.daterangepicker(pickerOpts, profiler.opProfile.onStatsGraphDatePickerChange);
            }

            // Display the graph area
            $overlay.show();

            // Render the graph
            var chart = nv.models
                    .scatterChart()
                    .showDistX(true)
                    .showDistY(true)
                    .color(d3.scale.category10().range());

            chart.xAxis
                .tickFormat(function (d) {
                    return d3.time.format('%H:%M%:%S')(new Date(d))
                });

            chart.yAxis
                .tickFormat(d3.format('d'));

            var graphData = outliers['data'] || [];

            d3.select('#StatsGraph_svg')
                .datum(graphData)
                .transition()
                .duration(500)
                .call(chart);
        },
        onFailure = function () {
            var $alertTemplate = $('#StatsGraph .f_alertTemplate'),
                $alert = $alertTemplate.clone().removeClass('f_alertTemplate').addClass('alert-danger');
            $alert.append('<p>' + $alertTemplate.data('errormessage') + '</p>');
            $alertTemplate.before($alert);
            $alert.show();
        };

    $.ajax(src, ajaxConfig).done(onDone).fail(onFailure);
};

profiler.opProfile.onShowStatsGraph = function (e) {
    'use strict';

    e.preventDefault();

    var $this = $(this),
        src = $this.attr('href'),
        options = {
            datum: [$this.data('datum')],
            scale: $this.data('scale') || ''
        };

    profiler.opProfile.loadStatsGraph(src, options);

    return false;
};

profiler.opProfile.onSubmitStatsGraphControlForm = function (e) {
    'use strict';

    e.preventDefault();

    var $this = $(this),
        src = $this.attr('action'),
        options = {
            datum: [],
            limit: $this.find('input[name="limit"]').val(),
            min: $this.find('input[name="min"]').val(),
            max: $this.find('input[name="max"]').val(),
            from: $this.find('input[name="from"]').val(),
            to: $this.find('input[name="to"]').val()
        };

    $this.find('select[name="datum"] option:selected').each(function () {
        options.datum.push($(this).val());
    });

    $this.parents('.modal').first().modal('hide');

    profiler.opProfile.loadStatsGraph(src, options);

    return false;
};

$(document).ready(function () {

    if (!profiler.chart) {
        throw new Error('profiler.chart api required!');
    }

    var cm = profiler.chart.createManager(),
        cp = profiler.opProfile,
        $documentMoveChart = $('#MovedDocumentChart');

    // Does only exist in update profiles
    if ($documentMoveChart.length === 1) {
        cm.createChart($documentMoveChart, cp.showDocumentMoveCharts).load();
    }

    $(document).on('click', '.f_opIssueControl button', cp.issueControl);
    $(document).on('click', '.f_showStatsGraph', cp.onShowStatsGraph);
    $('#StatsGraphControl').on('submit', cp.onSubmitStatsGraphControlForm);
});