package de.otto.mongodb.profiler.web;

import de.otto.mongodb.profiler.op.OpProfiler;
import de.otto.mongodb.profiler.op.QueryProfile;
import org.testng.annotations.Test;

import java.util.Arrays;
import java.util.Collection;
import java.util.Locale;

import static org.mockito.Mockito.doReturn;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;

public class OpProfilesPanelViewModelTest extends FunctionTest {

    private static QueryProfile profileMock(String ns, long eventCount) {
        final QueryProfile profile = mock(QueryProfile.class);
        when(profile.getEventCount()).thenReturn(eventCount);
        when(profile.getNs()).thenReturn(ns);
        return profile;
    }

    @Test
    public void shouldReturnPercentage() {

        // Given
        final Collection<? extends QueryProfile> queryProfiles = Arrays.asList(
                profileMock("ns-1", 10L),
                profileMock("ns-2", 90L)
        );
        final OpProfiler profiler = mock(OpProfiler.class);
        doReturn(queryProfiles).when(profiler).getQueryProfiles();

        final OpProfilesPanelViewModel model = new OpProfilesPanelViewModel(
                "connectionId",
                "database",
                profiler,
                OpProfilesPanelViewModel.RenderType.PANEL,
                Locale.ENGLISH);

        // When
        final String result = model.getEventCountProportion(queryProfiles.iterator().next());

        // Then
        assertEquals(result, "10%");
    }

}
