package de.otto.mongodb.profiler.web.util;

import com.mongodb.BasicDBList;
import com.mongodb.BasicDBObjectBuilder;
import com.mongodb.DBObject;
import de.otto.mongodb.profiler.web.FunctionTest;
import org.bson.types.Binary;
import org.bson.types.ObjectId;
import org.testng.annotations.Test;

import java.util.Date;
import java.util.regex.Pattern;

import static org.testng.Assert.assertNotNull;

public class BSONFormatTest extends FunctionTest {

    private static DBObject createObject() {

        final BasicDBList list = new BasicDBList();
        list.add(BasicDBObjectBuilder.start().get());
        list.add(BasicDBObjectBuilder.start().get());

        final Binary binary = new Binary(((byte) 0), new byte[]{0});
        final byte[] bytes = new byte[]{0};

        final Pattern pattern = Pattern.compile("[a-z]");

        return BasicDBObjectBuilder
                .start()
                .add("foo", "bar")
                .add("bar", "foo")
                .push("numbers")
                .add("aNumber", 1234)
                .pop()
                .push("dates")
                .add("aDate", new Date())
                .pop()
                .add("aList", list)
                .add("anObjectId", ObjectId.get())
                .add("binary", binary)
                .add("bytes", bytes)
                .add("pattern", pattern)
                .get();
    }

    @Test
    public void shouldFormatText() {

        // Given
        final DBObject dbo = createObject();
        final BSONFormat format = BSONFormat.getTextInstance(2);

        // When
        final String result = format.format(dbo);

        // Then
        assertNotNull(result);
        // System.out.println(result);
    }

    @Test
    public void shouldFormatHtml() {

        // Given
        final DBObject dbo = createObject();
        final BSONFormat format = BSONFormat.getHtmlInstance();

        // When
        final String result = format.format(dbo);

        // Then
        assertNotNull(result);
        // System.out.println(result);
    }

}
