/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler;

/**
 * This exception gets thrown when a database was not found. The profiler must not create a new database if the
 * requested one does not exist.
 *
 * @author Robert Gacki
 */
public class DatabaseDoesNotExistException extends Exception {

    private final String database;

    public DatabaseDoesNotExistException(String message, String database) {
        super(message);
        this.database = database;
    }

    /**
     * Returns the name of the database that does not exist.
     *
     * @return the name of the database
     */
    public String getDatabase() {
        return database;
    }
}
