/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler;

/**
 * A profiler that needs to be initialized and shut down.
 *
 * @author Robert Gacki
 */
public interface InitializingProfiler extends Profiler {

    /**
     * Initializes the profiler. This method must block until the profiler is initialized.
     */
    void initialize();

    /**
     * Shuts the profiler down and frees all resources. This method must block until the
     * profiler is shut down.
     */
    void shutdown();

}
