/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler;

/**
 * An exception that gets thrown when the name of the connection is invalid. The name may be invalid if certain
 * characters are missing, which may be required to create the identity of the connection.
 *
 * @author Robert Gacki
 */
public class InvalidConnectionNameException extends Exception {

    private final String name;

    public InvalidConnectionNameException(final String message, final String name) {
        super(message);
        this.name = name;
    }

    /**
     * Returns the name that is invalid.
     *
     * @return the name that is invalid
     */
    public String getName() {
        return name;
    }
}
