/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op;

/**
 * A profile for an operation that can be explained. This is just a marker type and should not be implemented as parent
 * type.
 *
 * @author Robert Gacki
 */
public interface ExplainableOpProfile extends OpProfile {

    /**
     * Returns the amount of explanations that were done with the query.
     *
     * @return the amount of explanations
     */
    int getExplanationCount();

    /**
     * Returns the explanations that were done with the query.
     *
     * @return the explanations
     */
    Iterable<Explanation> getExplanations();

    /**
     * Returns the last explanation for the query.
     *
     * @return the last explanation for the query
     */
    Explanation getLastExplanation();

}
