/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * An issue found for an Explanation.
 *
 * @author Robert Gacki
 */
public enum ExplanationIssue {

    FULL_TABLE_SCAN(Severity.WARNING),
    MISSING_INDEX(Severity.SEVERE),
    RESULTS_ORDERED_AFTER_SCAN(Severity.SEVERE);

    /**
     * The severity of the issue.
     *
     * @author Robert Gacki
     */
    public static enum Severity {
        SEVERE,
        WARNING;
    }

    private final Severity severity;

    /**
     * Creates a new explanation issue.
     *
     * @param severity the severity of the issue
     * @return the explanation issue
     */
    private ExplanationIssue(final Severity severity) {
        this.severity = checkNotNull(severity);
    }

    /**
     * Returns the severity of the issue.
     *
     * @return the severity of the issue
     */
    public Severity getSeverity() {
        return severity;
    }

    /**
     * Returns the code of the issue.
     *
     * @return the code of the issue
     */
    public String getCode() {
        return name();
    }
}
