/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op;

import com.mongodb.DBObject;

import java.util.Locale;

/**
 * A profile of a findandmodify command.
 *
 * @author Robert Gacki
 */
public interface FindAndModifyProfile extends UpdateProfile {

    public static final String TYPE_VALUE = "findandmodify";

    /**
     * The outcome of the operation.
     *
     * @author Robert Gacki
     */
    public static enum Outcome {

        /**
         * Findandmodify to remove documents.
         */
        REMOVE,

        /**
         * Findandmodify to update documents.
         */
        UPDATE,

        /**
         * Findandmodify to upsert documents.
         */
        UPSERT;

        private final String string = name().toLowerCase(Locale.ENGLISH);

        public static Outcome fromCommand(DBObject command) {
            if (Boolean.TRUE.equals(command.get("remove"))) {
                return REMOVE;
            } else if (command.get("update") != null) {
                return Boolean.TRUE.equals(command.get("upsert")) ? UPSERT : UPDATE;
            }
            return null;
        }

        public String toString() {
            return string;
        }
    }

    /**
     * Returns the outcome of the findandmodify operation.
     *
     * @return the outcome
     */
    Outcome getOutcome();

}
