/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op;

import com.mongodb.DBObject;
import org.joda.time.DateTime;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * A profiling data sample (entry).
 *
 * @author Robert Gacki
 */
public class ProfileEntry {

    private final DBObject data;
    private final DateTime ceatedAt;

    public ProfileEntry(final DBObject data,
                        final DateTime ceatedAt) {
        this.data = checkNotNull(data);
        this.ceatedAt = checkNotNull(ceatedAt);
    }

    /**
     * Returns the profiling data for this sample.
     *
     * @return the profiling data
     */
    public DBObject getData() {
        return data;
    }

    /**
     * Returns the date and time of the creation of the data.
     *
     * @return the date and time of the creation of the data
     */
    public DateTime getCeatedAt() {
        return ceatedAt;
    }
}
