/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op;

import com.mongodb.DBObject;

/**
 * A profile that is based on a database query resulting in documents being scanned.
 *
 * @author Robert Gacki
 */
public interface QueryProfile extends OpProfile, ExplainableOpProfile {

    /**
     * The type value: {@value #TYPE_VALUE}.
     */
    public static final String TYPE_VALUE = "query";

    /**
     * Returns the query of the operation.
     *
     * @return the query of the operation
     */
    DBObject getQuery();

    /**
     * Determines whether the query has a snapshot modifier. Returns {@code true} if the query is in snapshot mode. Else
     * {@code false} is returned.
     *
     * @return {@code true} if the query is in snapshot mode, else {@code false}
     */
    boolean isSnapshot();

}
