/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op.analyze;

import com.mongodb.DBObject;

/**
 * An analyzer that analyzes MongoDB profile documents.
 *
 * @author Robert Gacki
 */
public interface Analyzer {

    /**
     * <p>Takes a profile document and analyzes it. Returns {@code true} if the profile was handled
     * and requires no further step. Else, the profile will be passed to the next analyzer.</p>
     * <p/>
     *
     * @param dbo     the profile document
     * @param context the context
     * @return {@code true} if the analyzer handled the profile, else {@code false}
     */
    boolean analyze(DBObject dbo, AnalyzerContext context);

}
