/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op.analyze;

import com.mongodb.DBObject;

import static de.otto.mongodb.profiler.util.MongoSupport.require;

/**
 * The base class for command analysis.
 *
 * @author Robert Gacki
 */
public abstract class CommandAnalyzer implements Analyzer {


    /**
     * Checks whether the profile document has a command operation. If so, it delegates the profile document to
     * the {@link #analyzeCommand(com.mongodb.DBObject, AnalyzerContext)} method.
     */
    @Override
    public boolean analyze(DBObject dbo, AnalyzerContext context) {

        final String op = require("op", String.class, dbo);

        if (!"command".equals(op)) {
            return false;
        }

        return analyzeCommand(dbo, context);
    }

    /**
     * Does the same as explained in {@link Analyzer#analyze(com.mongodb.DBObject, AnalyzerContext)}, but always gets
     * a profile document that consists of a command operation.
     *
     * @param dbo     the profile of the command operation
     * @param context the analyzer context
     * @return {@code true} if the analyzer handled the profile, else {@code false}
     */
    protected abstract boolean analyzeCommand(DBObject dbo, AnalyzerContext context);

}
