/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.op.analyze;

import com.mongodb.DBObject;
import de.otto.mongodb.profiler.op.DocumentMoveMeasure;
import de.otto.mongodb.profiler.op.ProfileEntry;
import de.otto.mongodb.profiler.op.UpdateProfile;

/**
 * @author Robert Gacki
 */
class DefaultUpdateProfile extends DefaultQueryProfile implements UpdateProfile {

    private final DocumentMoveMeasure moveMeasure;

    public DefaultUpdateProfile(final String id,
                                final String ns,
                                final OutlierConfiguration outlierConfiguration,
                                final DBObject query) {
        super(id, ns, outlierConfiguration, query, false);
        moveMeasure = new DocumentMoveMeasure();
    }

    @Override
    public void add(ProfileEntry entry) {
        super.add(entry);
        final boolean moved = Boolean.TRUE.equals(entry.getData().get("moved"));
        if (moved) {
            moveMeasure.incrementMoved(entry.getCeatedAt().getMillis());
        } else {
            moveMeasure.incrementNormal(entry.getCeatedAt().getMillis());
        }
    }

    @Override
    public DocumentMoveMeasure getMoveMeasure() {
        return moveMeasure;
    }

    @Override
    public String getType() {
        return UpdateProfile.TYPE_VALUE;
    }
}
