/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.util;

import java.util.logging.Level;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * The logging facade. Currently uses java.util.logging as backend.
 *
 * @author Robert Gacki
 */
public class Logger {

    /**
     * Returns a logger for a class. The name of the logger will be the full qualified class name.
     *
     * @param clazz the class to return the logger for
     * @return the logger
     */
    public static Logger getLogger(Class<?> clazz) {
        return new Logger(checkNotNull(clazz));
    }

    private final java.util.logging.Logger logger;

    protected Logger(Class<?> clazz) {
        this.logger = java.util.logging.Logger.getLogger(clazz.getName());
    }

    public void error(Throwable t, String message, Object... args) {
        logger.log(Level.SEVERE, String.format(message, args), t);
    }

    public void warn(Throwable t, String message, Object... args) {
        logger.log(Level.WARNING, String.format(message, args), t);
    }

    public void info(Throwable t, String message, Object... args) {
        logger.log(Level.INFO, String.format(message, args), t);
    }

    public void debug(String message, Object... args) {
        logger.log(Level.FINE, String.format(message, args));
    }

    public void debug(Throwable t, String message, Object... args) {
        logger.log(Level.INFO, String.format(message, args), t);
    }

    public void trace(String message, Object... args) {
        logger.log(Level.FINER, String.format(message, args));
    }

}
