/*
 *  Copyright 2013 Robert Gacki <robert.gacki@cgi.com>
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package de.otto.mongodb.profiler.util;

import de.otto.mongodb.profiler.Profiler;

import java.util.concurrent.ThreadFactory;

/**
 * A thread factory that is used to create threads for profilers.
 *
 * @author Robert Gacki
 */
public class ProfilerThreadFactory implements ThreadFactory {

    private final Class<? extends Profiler> profilerType;
    private final String suffix;
    private final ThreadGroup threadGroup;

    public ProfilerThreadFactory(final Class<? extends Profiler> profilerType,
                                 final String suffix,
                                 final ThreadGroup threadGroup) {
        this.profilerType = profilerType;
        this.suffix = suffix;
        this.threadGroup = threadGroup;
    }

    @Override
    public Thread newThread(Runnable r) {
        return new Thread(threadGroup, r, profilerType.getSimpleName() + "-" + suffix);
    }
}
