package de.otto.mongodb.profiler;

import org.testng.annotations.Test;

import static org.testng.Assert.assertFalse;
import static org.testng.Assert.assertTrue;

public abstract class AbstractAsyncProfilerTest extends FunctionTest {

    protected abstract AbstractAsyncProfiler createProfiler(boolean execute);

    @Test
    public void shouldBeProfiling() {

        // Given

        // When
        final AbstractAsyncProfiler profiler = createProfiler(true);

        // Then
        assertTrue(profiler.isProfiling());
        assertTrue(profiler.getExecutionGuard().execute());
    }

    @Test
    public void shouldNotBeProfiling() {

        // Given

        // When
        final AbstractAsyncProfiler profiler = createProfiler(false);

        // Then
        assertFalse(profiler.isProfiling());
        assertFalse(profiler.getExecutionGuard().execute());
    }

    @Test
    public void shouldStopProfiling() {

        // Given
        final AbstractAsyncProfiler profiler = createProfiler(true);
        assertTrue(profiler.isProfiling());
        assertTrue(profiler.getExecutionGuard().execute());

        // When
        profiler.stopProfiling();

        // Then
        assertFalse(profiler.isProfiling());
        assertFalse(profiler.getExecutionGuard().execute());
    }

    @Test
    public void shouldContinueProfiling() {

        // Given
        final AbstractAsyncProfiler profiler = createProfiler(false);
        assertFalse(profiler.isProfiling());
        assertFalse(profiler.getExecutionGuard().execute());

        // When
        profiler.continueProfiling();

        // Then
        assertTrue(profiler.isProfiling());
        assertTrue(profiler.getExecutionGuard().execute());
    }

}
