package de.otto.mongodb.profiler;

import org.testng.annotations.Test;

import java.util.ArrayList;
import java.util.Deque;
import java.util.List;
import java.util.concurrent.TimeUnit;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertSame;

public class ChronoSamplerTest extends FunctionTest {

    private static class TestChronoMark {

        public final long time;

        private TestChronoMark(long time) {
            this.time = time;
        }
    }

    private static class SampleChronoMark extends TestChronoMark {

        public final List<TestChronoMark> marks;

        private SampleChronoMark(long time, Deque<TestChronoMark> marks) {
            super(time);
            this.marks = new ArrayList<>(marks);
        }
    }

    private static final ChronoSampler.Reduction REDUCTION = new ChronoSampler.Reduction<TestChronoMark, SampleChronoMark>() {

        @Override
        public SampleChronoMark reduce(long time, Deque<TestChronoMark> marks) {

            return new SampleChronoMark(time, marks);
        }
    };

    @Test
    public void shouldCreateSamples() {

        // Given
        final List<TestChronoMark> testChronoMarks = new ArrayList<TestChronoMark>() {{
            add(new TestChronoMark(0L));
            add(new TestChronoMark(1L));
            add(new TestChronoMark(500L));
            add(new TestChronoMark(999L));
            add(new TestChronoMark(1000L));
            add(new TestChronoMark(1001L));
        }};
        final ChronoSampler<TestChronoMark, SampleChronoMark> sampler =
                new ChronoSampler<TestChronoMark, SampleChronoMark>(1L, TimeUnit.SECONDS, REDUCTION);
        for (TestChronoMark mark : testChronoMarks) {
            sampler.add(mark.time, mark);
        }

        // When
        final List<SampleChronoMark> samples = sampler.finish();

        // Then
        assertEquals(samples.size(), 3);
        assertEquals(samples.get(0).time, 0L);
        assertEquals(samples.get(0).marks.size(), 1);
        assertSame(samples.get(0).marks.get(0), testChronoMarks.get(0));
        assertEquals(samples.get(1).time, 1000L);
        assertEquals(samples.get(1).marks.size(), 3);
        assertSame(samples.get(1).marks.get(0), testChronoMarks.get(1));
        assertSame(samples.get(1).marks.get(1), testChronoMarks.get(2));
        assertSame(samples.get(1).marks.get(2), testChronoMarks.get(3));
        assertEquals(samples.get(2).time, testChronoMarks.get(5).time);
        assertEquals(samples.get(2).marks.size(), 2);
        assertSame(samples.get(2).marks.get(0), testChronoMarks.get(4));
        assertSame(samples.get(2).marks.get(1), testChronoMarks.get(5));
    }

    @Test(expectedExceptions = IllegalArgumentException.class)
    public void shouldFailToAddNonChronologicalSequences() {

        // Given
        final TestChronoMark first = new TestChronoMark(1L);
        final TestChronoMark second = new TestChronoMark(0L);
        final ChronoSampler<TestChronoMark, SampleChronoMark> sampler =
                new ChronoSampler<TestChronoMark, SampleChronoMark>(1L, TimeUnit.SECONDS, REDUCTION);
        sampler.add(first.time, first);

        // When
        sampler.add(second.time, second);

        // Then
    }

}
