package de.otto.mongodb.profiler.collection;

import com.mongodb.BasicDBObjectBuilder;
import com.mongodb.DBObject;
import de.otto.mongodb.profiler.FunctionTest;
import org.testng.annotations.Test;

import static org.testng.Assert.assertEquals;

public class DefaultCollectionProfileTest extends FunctionTest {

    @Test
    public void shouldAddStats() {

        // Given
        final DBObject stats = BasicDBObjectBuilder
                .start()
                .add("count", 177L)
                .add("paddingFactor", 1.77)
                .add("size", 277L)
                .add("storageSize", 377L)
                .get();
        final DefaultCollectionProfile profile = new DefaultCollectionProfile("mydb.mycollection", true);

        // When
        profile.add(stats);

        // Then
        assertEquals(profile.getCollectionName(), "mydb.mycollection");
        assertEquals(profile.isCappedCollection(), true);
        assertEquals(profile.getDocumentCountMeasure().getMax(), ((double) 177L));
        assertEquals(profile.getPaddingFactorMeasure().getMax(), 1.77);
        assertEquals(profile.getMarks().size(), 1);
        final DefaultCollectionProfile.Mark mark = profile.getMarks().getLast();
        assertEquals(mark.getDocumentCount(), 177L);
        assertEquals(mark.getDataSize(), 277L);
        assertEquals(mark.getDataStorageSize(), 377L);
        assertEquals(mark.getPaddingFactor(), 1.77);
    }

}
