package de.otto.mongodb.profiler.op;

import de.otto.mongodb.profiler.FunctionTest;
import org.testng.annotations.Test;

import java.util.Iterator;

import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertFalse;

public class DocumentMoveMeasureTest extends FunctionTest {

    @Test
    public void shouldHaveDefaults() {

        // Given
        final DocumentMoveMeasure measure = new DocumentMoveMeasure();

        // When

        // Then
        assertEquals(measure.getMoved(), 0L);
        assertEquals(measure.getTotal(), 0L);
        assertFalse(measure.getMarks().iterator().hasNext());
        assertEquals(measure.getRatio().doubleValue(), 0.0);
    }

    @Test
    public void shouldIncrementMovedCount() {

        // Given
        final DocumentMoveMeasure measure = new DocumentMoveMeasure();

        // When
        measure.incrementMoved(1007L);

        // Then
        assertEquals(measure.getMoved(), 1L);
        assertEquals(measure.getTotal(), 1L);
        assertEquals(measure.getRatio().doubleValue(), 1.0);
        final Iterator<DocumentMoveMeasure.Mark> marks = measure.getMarks().iterator();
        final DocumentMoveMeasure.Mark mark = marks.next();
        assertEquals(mark.moved, true);
        assertEquals(mark.movedCount, 1L);
        assertEquals(mark.normalCount, 0L);
        assertEquals(mark.ratio.doubleValue(), 1.0);
        assertEquals(mark.time, 1007L);
        assertFalse(marks.hasNext());
    }

    @Test
    public void shouldIncrementNormalCount() {

        // Given
        final DocumentMoveMeasure measure = new DocumentMoveMeasure();

        // When
        measure.incrementNormal(1007L);

        // Then
        assertEquals(measure.getMoved(), 0L);
        assertEquals(measure.getTotal(), 1L);
        assertEquals(measure.getRatio().doubleValue(), 0.0);
        final Iterator<DocumentMoveMeasure.Mark> marks = measure.getMarks().iterator();
        final DocumentMoveMeasure.Mark mark = marks.next();
        assertEquals(mark.moved, false);
        assertEquals(mark.movedCount, 0L);
        assertEquals(mark.normalCount, 1L);
        assertEquals(mark.ratio.doubleValue(), 0.0);
        assertEquals(mark.time, 1007L);
        assertFalse(marks.hasNext());
    }

    @Test
    public void shouldCalculateRatio() {

        // Given
        final DocumentMoveMeasure measure = new DocumentMoveMeasure();

        // When
        measure.incrementNormal(1007L);
        measure.incrementMoved(2007L);

        // Then
        assertEquals(measure.getMoved(), 1L);
        assertEquals(measure.getTotal(), 2L);
        assertEquals(measure.getRatio().doubleValue(), 0.5);
        final Iterator<DocumentMoveMeasure.Mark> marks = measure.getMarks().iterator();
        final DocumentMoveMeasure.Mark toBeNormal = marks.next();
        assertEquals(toBeNormal.moved, false);
        assertEquals(toBeNormal.movedCount, 0L);
        assertEquals(toBeNormal.normalCount, 1L);
        assertEquals(toBeNormal.ratio.doubleValue(), 0.0);
        assertEquals(toBeNormal.time, 1007L);
        final DocumentMoveMeasure.Mark toBeMoved = marks.next();
        assertEquals(toBeMoved.moved, true);
        assertEquals(toBeMoved.movedCount, 1L);
        assertEquals(toBeMoved.normalCount, 1L);
        assertEquals(toBeMoved.ratio.doubleValue(), 0.5);
        assertEquals(toBeMoved.time, 2007L);
        assertFalse(marks.hasNext());
    }

}
